@@ -26,6 +26,7 @@ from oslo_log import log as logging
 from oslo_utils import encodeutils
 from oslo_utils import excutils
 from oslo_utils import strutils
+import six
 from webob.exc import HTTPBadRequest
 from webob.exc import HTTPConflict
 from webob.exc import HTTPForbidden
@@ -45,17 +46,14 @@ from glance.api.v1 import upload_utils
 from glance.common import exception
 from glance.common import property_utils
 from glance.common import store_utils
+from glance.common import timeutils
 from glance.common import utils
 from glance.common import wsgi
-from glance import i18n
+from glance.i18n import _, _LE, _LI, _LW
 from glance import notifier
 import glance.registry.client.v1.api as registry
 
 LOG = logging.getLogger(__name__)
-_ = i18n._
-_LE = i18n._LE
-_LI = i18n._LI
-_LW = i18n._LW
 SUPPORTED_PARAMS = glance.api.v1.SUPPORTED_PARAMS
 SUPPORTED_FILTERS = glance.api.v1.SUPPORTED_FILTERS
 ACTIVE_IMMUTABLE = glance.api.v1.ACTIVE_IMMUTABLE
@@ -68,6 +66,28 @@ CONF.import_opt('container_formats', 'glance.common.config',
 CONF.import_opt('image_property_quota', 'glance.common.config')
 
 
+def _validate_time(req, values):
+    """Validates time formats for updated_at, created_at and deleted_at.
+    'strftime' only allows values after 1900 in glance v1 so this is enforced
+    here. This was introduced to keep modularity.
+    """
+    for time_field in ['created_at', 'updated_at', 'deleted_at']:
+        if time_field in values and values[time_field]:
+            try:
+                time = timeutils.parse_isotime(values[time_field])
+                # On Python 2, datetime.datetime.strftime() raises a ValueError
+                # for years older than 1900. On Python 3, years older than 1900
+                # are accepted. But we explicitly want to reject timestamps
+                # older than January 1st, 1900 for Glance API v1.
+                if time.year < 1900:
+                    raise ValueError
+                values[time_field] = time.strftime(
+                    timeutils.PERFECT_TIME_FORMAT)
+            except ValueError:
+                msg = (_("Invalid time format for %s.") % time_field)
+                raise HTTPBadRequest(explanation=msg, request=req)
+
+
 def _validate_format(req, values):
     """Validates disk_format and container_format fields
 
@@ -103,6 +123,7 @@ def _validate_format(req, values):
 
 def validate_image_meta(req, values):
     _validate_format(req, values)
+    _validate_time(req, values)
 
     name = values.get('name')
     checksum = values.get('checksum')
@@ -171,7 +192,7 @@ class Controller(controller.BaseController):
         try:
             self.policy.enforce(req.context, action, target)
         except exception.Forbidden:
-            LOG.debug("User not permitted to perform '%s' action" % action)
+            LOG.debug("User not permitted to perform '%s' action", action)
             raise HTTPForbidden()
 
     def _enforce_image_property_quota(self,
@@ -183,7 +204,7 @@ class Controller(controller.BaseController):
             # If value is negative, allow unlimited number of properties
             return
 
-        props = image_meta['properties'].keys()
+        props = list(image_meta['properties'].keys())
 
         # NOTE(ameade): If we are not removing existing properties,
         # take them in to account
@@ -209,7 +230,7 @@ class Controller(controller.BaseController):
         :param create_props: List of properties to check
         :param req: The WSGI/Webob Request object
 
-        :raises HTTPForbidden if request forbidden to create a property
+        :raises: HTTPForbidden if request forbidden to create a property
         """
         if property_utils.is_property_protection_enabled():
             for key in create_props:
@@ -229,7 +250,7 @@ class Controller(controller.BaseController):
         :param req: The WSGI/Webob Request object
         """
         if property_utils.is_property_protection_enabled():
-            for key in image_meta['properties'].keys():
+            for key in list(image_meta['properties'].keys()):
                 if (self.prop_enforcer.check_property_rules(
                         key, 'read', req.context) is False):
                     image_meta['properties'].pop(key)
@@ -249,7 +270,7 @@ class Controller(controller.BaseController):
         :param orig_meta: Mapping of existing metadata about image
         :param req: The WSGI/Webob Request object
 
-        :raises HTTPForbidden if request forbidden to create a property
+        :raises: HTTPForbidden if request forbidden to create a property
         """
         if property_utils.is_property_protection_enabled():
             for key in update_props:
@@ -281,7 +302,7 @@ class Controller(controller.BaseController):
         :param orig_meta: Mapping of existing metadata about image
         :param req: The WSGI/Webob Request object
 
-        :raises HTTPForbidden if request forbidden to create a property
+        :raises: HTTPForbidden if request forbidden to create a property
         """
         if property_utils.is_property_protection_enabled():
             for key in delete_props:
@@ -424,7 +445,7 @@ class Controller(controller.BaseController):
         :param id: The opaque image identifier
         :retval similar to 'show' method but without image_data
 
-        :raises HTTPNotFound if image metadata is not available to user
+        :raises: HTTPNotFound if image metadata is not available to user
         """
         self._enforce(req, 'get_image')
         image_meta = self.get_image_meta_or_404(req, id)
@@ -441,26 +462,32 @@ class Controller(controller.BaseController):
         or copy-from headers) are supported. Otherwise we reject
         with 400 "Bad Request".
         """
-        if source:
-            if store_utils.validate_external_location(source):
-                return source
-            else:
+        if store_utils.validate_external_location(source):
+            return source
+        else:
+            if source:
                 msg = _("External sources are not supported: '%s'") % source
-                LOG.warn(msg)
-                raise HTTPBadRequest(explanation=msg,
-                                     request=req,
-                                     content_type="text/plain")
+            else:
+                msg = _("External source should not be empty")
+            LOG.warn(msg)
+            raise HTTPBadRequest(explanation=msg,
+                                 request=req,
+                                 content_type="text/plain")
 
     @staticmethod
     def _copy_from(req):
         return req.headers.get('x-glance-api-copy-from')
 
     def _external_source(self, image_meta, req):
-        source = image_meta.get('location')
-        if source is not None:
+        if 'location' in image_meta:
             self._enforce(req, 'set_image_location')
-        else:
+            source = image_meta['location']
+        elif 'x-glance-api-copy-from' in req.headers:
             source = Controller._copy_from(req)
+        else:
+            # we have an empty external source value
+            # so we are creating "draft" of the image and no need validation
+            return None
         return Controller._validate_source(source, req)
 
     @staticmethod
@@ -493,7 +520,7 @@ class Controller(controller.BaseController):
         :param req: The WSGI/Webob Request object
         :param id: The opaque image identifier
 
-        :raises HTTPNotFound if image is not available to user
+        :raises: HTTPNotFound if image is not available to user
         """
 
         self._enforce(req, 'get_image')
@@ -535,8 +562,8 @@ class Controller(controller.BaseController):
         :param id: The opaque image identifier
         :param image_meta: The image metadata
 
-        :raises HTTPConflict if image already exists
-        :raises HTTPBadRequest if image metadata is not valid
+        :raises: HTTPConflict if image already exists
+        :raises: HTTPBadRequest if image metadata is not valid
         """
         location = self._external_source(image_meta, req)
         scheme = image_meta.get('store')
@@ -553,8 +580,8 @@ class Controller(controller.BaseController):
             try:
                 backend = store.get_store_from_location(location)
             except (store.UnknownScheme, store.BadStoreUri):
+                LOG.debug("Invalid location %s", location)
                 msg = _("Invalid location %s") % location
-                LOG.debug(msg)
                 raise HTTPBadRequest(explanation=msg,
                                      request=req,
                                      content_type="text/plain")
@@ -606,7 +633,7 @@ class Controller(controller.BaseController):
         :param req: The WSGI/Webob Request object
         :param image_meta: Mapping of metadata about image
 
-        :raises HTTPConflict if image already exists
+        :raises: HTTPConflict if image already exists
         :retval The location where the image was stored
         """
 
@@ -687,7 +714,7 @@ class Controller(controller.BaseController):
                 # Delete image data since it has been superseded by another
                 # upload and re-raise.
                 LOG.debug("duplicate operation - deleting image data for "
-                          " %(id)s (location:%(location)s)" %
+                          " %(id)s (location:%(location)s)",
                           {'id': image_id, 'location': image_meta['location']})
                 upload_utils.initiate_deletion(req, location_data, image_id)
         except exception.Invalid as e:
@@ -712,7 +739,7 @@ class Controller(controller.BaseController):
         location_data = self._upload(req, image_meta)
         image_id = image_meta['id']
         LOG.info(_LI("Uploaded data of image %s from request "
-                     "payload successfully.") % image_id)
+                     "payload successfully."), image_id)
 
         if location_data:
             try:
@@ -761,7 +788,7 @@ class Controller(controller.BaseController):
     def _handle_source(self, req, image_id, image_meta, image_data):
         copy_from = self._copy_from(req)
         location = image_meta.get('location')
-        sources = filter(lambda x: x, (copy_from, location, image_data))
+        sources = [obj for obj in (copy_from, location, image_data) if obj]
         if len(sources) >= 2:
             msg = _("It's invalid to provide multiple image sources.")
             LOG.warn(msg)
@@ -870,7 +897,7 @@ class Controller(controller.BaseController):
         :param image_meta: Mapping of metadata about image
         :param image_data: Actual image data that is to be stored
 
-        :raises HTTPBadRequest if x-image-meta-location is missing
+        :raises: HTTPBadRequest if x-image-meta-location is missing
                 and the request body is not application/octet-stream
                 image data.
         """
@@ -938,7 +965,7 @@ class Controller(controller.BaseController):
             # modify certain core metadata keys
             for key in ACTIVE_IMMUTABLE:
                 if ((orig_status == 'active' or orig_status == 'deactivated')
-                        and image_meta.get(key) is not None
+                        and key in image_meta
                         and image_meta.get(key) != orig_image_meta.get(key)):
                     msg = _("Forbidden to modify '%(key)s' of %(status)s "
                             "image.") % {'key': key, 'status': orig_status}
@@ -947,7 +974,7 @@ class Controller(controller.BaseController):
                                         content_type="text/plain")
 
         for key in IMMUTABLE:
-            if (image_meta.get(key) is not None and
+            if (key in image_meta and
                     image_meta.get(key) != orig_image_meta.get(key)):
                 msg = _("Forbidden to modify '%s' of image.") % key
                 raise HTTPForbidden(explanation=msg,
@@ -1075,9 +1102,9 @@ class Controller(controller.BaseController):
         :param req: The WSGI/Webob Request object
         :param id: The opaque image identifier
 
-        :raises HttpBadRequest if image registry is invalid
-        :raises HttpNotFound if image or any chunk is not available
-        :raises HttpUnauthorized if image or any chunk is not
+        :raises: HttpBadRequest if image registry is invalid
+        :raises: HttpNotFound if image or any chunk is not available
+        :raises: HttpUnauthorized if image or any chunk is not
                 deleteable by the requesting user
         """
         self._enforce(req, 'delete_image')
@@ -1166,7 +1193,7 @@ class Controller(controller.BaseController):
         :param request: The WSGI/Webob Request object
         :param scheme: The backend store scheme
 
-        :raises HTTPBadRequest if store does not exist
+        :raises: HTTPBadRequest if store does not exist
         """
         try:
             return store.get_store_from_scheme(scheme)
@@ -1208,7 +1235,7 @@ class ImageDeserializer(wsgi.JSONRequestDeserializer):
             # gets the correct image data
             request.body_file = data
 
-        elif image_size > CONF.image_size_cap:
+        elif image_size is not None and image_size > CONF.image_size_cap:
             max_image_size = CONF.image_size_cap
             msg = (_("Denying attempt to upload image larger than %d"
                      " bytes.") % max_image_size)
@@ -1233,11 +1260,16 @@ class ImageSerializer(wsgi.JSONResponseSerializer):
 
     def _inject_location_header(self, response, image_meta):
         location = self._get_image_location(image_meta)
-        response.headers['Location'] = location.encode('utf-8')
+        if six.PY2:
+            location = location.encode('utf-8')
+        response.headers['Location'] = location
 
     def _inject_checksum_header(self, response, image_meta):
         if image_meta['checksum'] is not None:
-            response.headers['ETag'] = image_meta['checksum'].encode('utf-8')
+            checksum = image_meta['checksum']
+            if six.PY2:
+                checksum = checksum.encode('utf-8')
+            response.headers['ETag'] = checksum
 
     def _inject_image_meta_headers(self, response, image_meta):
         """
@@ -1254,7 +1286,10 @@ class ImageSerializer(wsgi.JSONResponseSerializer):
         headers = utils.image_meta_to_http_headers(image_meta)
 
         for k, v in headers.items():
-            response.headers[k.encode('utf-8')] = v.encode('utf-8')
+            if six.PY3:
+                response.headers[str(k)] = str(v)
+            else:
+                response.headers[k.encode('utf-8')] = v.encode('utf-8')
 
     def _get_image_location(self, image_meta):
         """Build a relative url to reach the image defined by image_meta."""
