@@ -23,15 +23,12 @@ from glance.common import exception
 from glance.common import store_utils
 from glance.common import utils
 import glance.db
-from glance import i18n
+from glance.i18n import _, _LE, _LI
 import glance.registry.client.v1.api as registry
 
 
 CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
-_ = i18n._
-_LE = i18n._LE
-_LI = i18n._LI
 
 
 def initiate_deletion(req, location_data, id):
@@ -124,7 +121,7 @@ def upload_data_to_store(req, image_meta, image_data, store, notifier):
         except exception.StorageQuotaFull:
             with excutils.save_and_reraise_exception():
                 LOG.info(_LI('Cleaning up %s after exceeding '
-                             'the quota') % image_id)
+                             'the quota'), image_id)
                 store_utils.safe_delete_from_backend(
                     req.context, image_meta['id'], location_data)
 
@@ -179,8 +176,8 @@ def upload_data_to_store(req, image_meta, image_data, store, notifier):
             initiate_deletion(req, location_data, image_id)
             raise webob.exc.HTTPUnauthorized(explanation=e.msg, request=req)
         except exception.ImageNotFound:
-            msg = _LI("Image %s could not be found after upload. The image may"
-                      " have been deleted during the upload.") % image_id
+            msg = _("Image %s could not be found after upload. The image may"
+                    " have been deleted during the upload.") % image_id
             LOG.info(msg)
 
             # NOTE(jculp): we need to clean up the datastore if an image
