@@ -20,7 +20,6 @@ from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_serialization import jsonutils as json
 from oslo_utils import encodeutils
-from oslo_utils import timeutils
 import six
 import six.moves.urllib.parse as urlparse
 import webob.exc
@@ -28,22 +27,22 @@ import webob.exc
 from glance.api import policy
 from glance.common import exception
 from glance.common import location_strategy
+from glance.common import timeutils
 from glance.common import utils
 from glance.common import wsgi
 import glance.db
 import glance.gateway
-from glance import i18n
+from glance.i18n import _, _LW
 import glance.notifier
 import glance.schema
 
 LOG = logging.getLogger(__name__)
-_ = i18n._
-_LW = i18n._LW
 
 CONF = cfg.CONF
 CONF.import_opt('disk_formats', 'glance.common.config', group='image_format')
 CONF.import_opt('container_formats', 'glance.common.config',
                 group='image_format')
+CONF.import_opt('show_multiple_locations', 'glance.common.config')
 
 
 class ImagesController(object):
@@ -64,31 +63,26 @@ class ImagesController(object):
             image = image_factory.new_image(extra_properties=extra_properties,
                                             tags=tags, **image)
             image_repo.add(image)
-        except exception.DuplicateLocation as dup:
-            raise webob.exc.HTTPBadRequest(explanation=dup.msg)
-        except exception.Invalid as e:
+        except (exception.DuplicateLocation,
+                exception.Invalid) as e:
             raise webob.exc.HTTPBadRequest(explanation=e.msg)
+        except (exception.ReservedProperty,
+                exception.ReadonlyProperty) as e:
+            raise webob.exc.HTTPForbidden(explanation=e.msg)
         except exception.Forbidden as e:
             LOG.debug("User not permitted to create image")
             raise webob.exc.HTTPForbidden(explanation=e.msg)
-        except exception.InvalidParameterValue as e:
-            raise webob.exc.HTTPBadRequest(explanation=e.msg)
         except exception.LimitExceeded as e:
             LOG.warn(encodeutils.exception_to_unicode(e))
             raise webob.exc.HTTPRequestEntityTooLarge(
                 explanation=e.msg, request=req, content_type='text/plain')
-        except exception.Duplicate as dupex:
-            raise webob.exc.HTTPConflict(explanation=dupex.msg)
-        except exception.ReservedProperty as e:
-            raise webob.exc.HTTPForbidden(explanation=e.msg)
-        except exception.ReadonlyProperty as e:
-            raise webob.exc.HTTPForbidden(explanation=e.msg)
-        except TypeError as e:
-            LOG.debug(encodeutils.exception_to_unicode(e))
-            raise webob.exc.HTTPBadRequest(
-                explanation=encodeutils.exception_to_unicode(e))
+        except exception.Duplicate as e:
+            raise webob.exc.HTTPConflict(explanation=e.msg)
         except exception.NotAuthenticated as e:
             raise webob.exc.HTTPUnauthorized(explanation=e.msg)
+        except TypeError as e:
+            LOG.debug(encodeutils.exception_to_unicode(e))
+            raise webob.exc.HTTPBadRequest(explanation=e)
 
         return image
 
@@ -117,7 +111,9 @@ class ImagesController(object):
             if len(images) != 0 and len(images) == limit:
                 result['next_marker'] = images[-1].image_id
         except (exception.NotFound, exception.InvalidSortKey,
-                exception.InvalidFilterRangeValue) as e:
+                exception.InvalidFilterRangeValue,
+                exception.InvalidParameterValue,
+                exception.InvalidFilterOperatorValue) as e:
             raise webob.exc.HTTPBadRequest(explanation=e.msg)
         except exception.Forbidden as e:
             LOG.debug("User not permitted to retrieve images index")
@@ -147,7 +143,6 @@ class ImagesController(object):
 
             for change in changes:
                 change_method_name = '_do_%s' % change['op']
-                assert hasattr(self, change_method_name)
                 change_method = getattr(self, change_method_name)
                 change_method(req, image, change)
 
@@ -160,8 +155,6 @@ class ImagesController(object):
         except exception.Forbidden as e:
             LOG.debug("User not permitted to update image '%s'", image_id)
             raise webob.exc.HTTPForbidden(explanation=e.msg)
-        except exception.InvalidParameterValue as e:
-            raise webob.exc.HTTPBadRequest(explanation=e.msg)
         except exception.StorageQuotaFull as e:
             msg = (_("Denying attempt to upload image because it exceeds the"
                      " quota: %s") % encodeutils.exception_to_unicode(e))
@@ -181,7 +174,10 @@ class ImagesController(object):
         path = change['path']
         path_root = path[0]
         value = change['value']
-        if path_root == 'locations':
+        if path_root == 'locations' and value == []:
+            msg = _("Cannot set locations to empty list.")
+            raise webob.exc.HTTPForbidden(msg)
+        elif path_root == 'locations' and value != []:
             self._do_replace_locations(image, value)
         elif path_root == 'owner' and req.context.is_admin == False:
             msg = _("Owner can't be updated by non admin.")
@@ -217,7 +213,10 @@ class ImagesController(object):
         path = change['path']
         path_root = path[0]
         if path_root == 'locations':
-            self._do_remove_locations(image, path[1])
+            try:
+                self._do_remove_locations(image, path[1])
+            except exception.Forbidden as e:
+                raise webob.exc.HTTPForbidden(e.msg)
         else:
             if hasattr(image, path_root):
                 msg = _("Property %s may not be removed.")
@@ -250,6 +249,8 @@ class ImagesController(object):
                     "exc": e.msg})
             LOG.warn(msg)
             raise webob.exc.HTTPConflict(explanation=msg)
+        except glance_store.exceptions.HasSnapshot as e:
+            raise webob.exc.HTTPConflict(explanation=e.msg)
         except exception.InvalidImageStatusTransition as e:
             raise webob.exc.HTTPBadRequest(explanation=e.msg)
         except exception.NotAuthenticated as e:
@@ -268,28 +269,29 @@ class ImagesController(object):
         return pos
 
     def _do_replace_locations(self, image, value):
-        if len(image.locations) > 0 and len(value) > 0:
-            msg = _("Cannot replace locations from a non-empty "
-                    "list to a non-empty list.")
-            raise webob.exc.HTTPBadRequest(explanation=msg)
-        if len(value) == 0:
-            # NOTE(zhiyan): this actually deletes the location
-            # from the backend store.
-            del image.locations[:]
-            if image.status == 'active':
-                image.status = 'queued'
-        else:   # NOTE(zhiyan): len(image.locations) == 0
-            try:
-                image.locations = value
-                if image.status == 'queued':
-                    image.status = 'active'
-            except (exception.BadStoreUri, exception.DuplicateLocation) as bse:
-                raise webob.exc.HTTPBadRequest(explanation=bse.msg)
-            except ValueError as ve:    # update image status failed.
-                raise webob.exc.HTTPBadRequest(
-                    explanation=encodeutils.exception_to_unicode(ve))
+        if CONF.show_multiple_locations == False:
+            msg = _("It's not allowed to update locations if locations are "
+                    "invisible.")
+            raise webob.exc.HTTPForbidden(explanation=msg)
+
+        try:
+            # NOTE(flwang): _locations_proxy's setattr method will check if
+            # the update is acceptable.
+            image.locations = value
+            if image.status == 'queued':
+                image.status = 'active'
+        except (exception.BadStoreUri, exception.DuplicateLocation) as e:
+            raise webob.exc.HTTPBadRequest(explanation=e.msg)
+        except ValueError as ve:    # update image status failed.
+            raise webob.exc.HTTPBadRequest(
+                explanation=encodeutils.exception_to_unicode(ve))
 
     def _do_add_locations(self, image, path_pos, value):
+        if CONF.show_multiple_locations == False:
+            msg = _("It's not allowed to add locations if locations are "
+                    "invisible.")
+            raise webob.exc.HTTPForbidden(explanation=msg)
+
         pos = self._get_locations_op_pos(path_pos,
                                          len(image.locations), True)
         if pos is None:
@@ -299,13 +301,23 @@ class ImagesController(object):
             image.locations.insert(pos, value)
             if image.status == 'queued':
                 image.status = 'active'
-        except (exception.BadStoreUri, exception.DuplicateLocation) as bse:
-            raise webob.exc.HTTPBadRequest(explanation=bse.msg)
-        except ValueError as ve:    # update image status failed.
+        except (exception.BadStoreUri, exception.DuplicateLocation) as e:
+            raise webob.exc.HTTPBadRequest(explanation=e.msg)
+        except ValueError as e:    # update image status failed.
             raise webob.exc.HTTPBadRequest(
-                explanation=encodeutils.exception_to_unicode(ve))
+                explanation=encodeutils.exception_to_unicode(e))
 
     def _do_remove_locations(self, image, path_pos):
+        if CONF.show_multiple_locations == False:
+            msg = _("It's not allowed to remove locations if locations are "
+                    "invisible.")
+            raise webob.exc.HTTPForbidden(explanation=msg)
+
+        if len(image.locations) == 1:
+            LOG.debug("User forbidden to remove last location of image %s",
+                      image.image_id)
+            msg = _("Cannot remove last location in the image.")
+            raise exception.Forbidden(msg)
         pos = self._get_locations_op_pos(path_pos,
                                          len(image.locations), False)
         if pos is None:
@@ -315,11 +327,11 @@ class ImagesController(object):
             # NOTE(zhiyan): this actually deletes the location
             # from the backend store.
             image.locations.pop(pos)
+        # TODO(jokke): Fix this, we should catch what store throws and
+        # provide definitely something else than IternalServerError to user.
         except Exception as e:
             raise webob.exc.HTTPInternalServerError(
                 explanation=encodeutils.exception_to_unicode(e))
-        if len(image.locations) == 0 and image.status == 'active':
-            image.status = 'queued'
 
 
 class RequestDeserializer(wsgi.JSONRequestDeserializer):
@@ -331,7 +343,7 @@ class RequestDeserializer(wsgi.JSONRequestDeserializer):
     _reserved_properties = ('location', 'deleted', 'deleted_at')
     _base_properties = ('checksum', 'created_at', 'container_format',
                         'disk_format', 'id', 'min_disk', 'min_ram', 'name',
-                        'size', 'virtual_size', 'status', 'tags',
+                        'size', 'virtual_size', 'status', 'tags', 'owner',
                         'updated_at', 'visibility', 'protected')
     _available_sort_keys = ('name', 'status', 'container_format',
                             'disk_format', 'size', 'id', 'created_at',
@@ -480,7 +492,7 @@ class RequestDeserializer(wsgi.JSONRequestDeserializer):
             msg = _("Attribute '%s' is reserved.") % path_root
             raise webob.exc.HTTPForbidden(explanation=six.text_type(msg))
 
-        if change['op'] == 'delete':
+        if change['op'] == 'remove':
             return
 
         partial_image = None
@@ -559,7 +571,8 @@ class RequestDeserializer(wsgi.JSONRequestDeserializer):
 
             if not op == 'remove':
                 change['value'] = self._get_change_value(raw_change, op)
-                self._validate_change(change)
+
+            self._validate_change(change)
 
             changes.append(change)
 
@@ -619,7 +632,7 @@ class RequestDeserializer(wsgi.JSONRequestDeserializer):
         """
         Process sorting params.
         Currently glance supports two sorting syntax: classic and new one,
-        that is uniform for all Openstack projects.
+        that is uniform for all OpenStack projects.
         Classic syntax: sort_key=name&sort_dir=asc&sort_key=size&sort_dir=desc
         New syntax: sort=name:asc,size:desc
         """
@@ -721,7 +734,13 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
         return base_href
 
     def _format_image(self, image):
-        image_view = dict()
+
+        def _get_image_locations(image):
+            try:
+                return list(image.locations)
+            except exception.Forbidden:
+                return []
+
         try:
             image_view = dict(image.extra_properties)
             attributes = ['name', 'disk_format', 'container_format',
@@ -735,7 +754,7 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
             image_view['updated_at'] = timeutils.isotime(image.updated_at)
 
             if CONF.show_multiple_locations:
-                locations = list(image.locations)
+                locations = _get_image_locations(image)
                 if locations:
                     image_view['locations'] = []
                     for loc in locations:
@@ -752,9 +771,10 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
                               "for image %s", image.image_id)
 
             if CONF.show_image_direct_url:
-                if image.locations:
+                locations = _get_image_locations(image)
+                if locations:
                     # Choose best location configured strategy
-                    l = location_strategy.choose_best_location(image.locations)
+                    l = location_strategy.choose_best_location(locations)
                     image_view['direct_url'] = l['url']
                 else:
                     LOG.debug("There is not available location "
@@ -765,9 +785,9 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
             image_view['file'] = self._get_image_href(image, 'file')
             image_view['schema'] = '/v2/schemas/image'
             image_view = self.schema.filter(image_view)  # domain
+            return image_view
         except exception.Forbidden as e:
             raise webob.exc.HTTPForbidden(explanation=e.msg)
-        return image_view
 
     def create(self, response, image):
         response.status_int = 201
@@ -824,7 +844,8 @@ def get_base_properties():
         },
         'status': {
             'type': 'string',
-            'description': _('Status of the image (READ-ONLY)'),
+            'readOnly': True,
+            'description': _('Status of the image'),
             'enum': ['queued', 'saving', 'active', 'killed',
                      'deleted', 'pending_delete', 'deactivated'],
         },
@@ -839,7 +860,8 @@ def get_base_properties():
         },
         'checksum': {
             'type': ['null', 'string'],
-            'description': _('md5 hash of image contents. (READ-ONLY)'),
+            'readOnly': True,
+            'description': _('md5 hash of image contents.'),
             'maxLength': 32,
         },
         'owner': {
@@ -849,11 +871,13 @@ def get_base_properties():
         },
         'size': {
             'type': ['null', 'integer'],
-            'description': _('Size of image file in bytes (READ-ONLY)'),
+            'readOnly': True,
+            'description': _('Size of image file in bytes'),
         },
         'virtual_size': {
             'type': ['null', 'integer'],
-            'description': _('Virtual size of image in bytes (READ-ONLY)'),
+            'readOnly': True,
+            'description': _('Virtual size of image in bytes'),
         },
         'container_format': {
             'type': ['null', 'string'],
@@ -867,16 +891,18 @@ def get_base_properties():
         },
         'created_at': {
             'type': 'string',
+            'readOnly': True,
             'description': _('Date and time of image registration'
-                             ' (READ-ONLY)'),
+                             ),
             # TODO(bcwaldon): our jsonschema library doesn't seem to like the
             # format attribute, figure out why!
             # 'format': 'date-time',
         },
         'updated_at': {
             'type': 'string',
+            'readOnly': True,
             'description': _('Date and time of the last image modification'
-                             ' (READ-ONLY)'),
+                             ),
             # 'format': 'date-time',
         },
         'tags': {
@@ -889,8 +915,9 @@ def get_base_properties():
         },
         'direct_url': {
             'type': 'string',
+            'readOnly': True,
             'description': _('URL to access the image file kept in external '
-                             'store (READ-ONLY)'),
+                             'store'),
         },
         'min_ram': {
             'type': 'integer',
@@ -903,15 +930,18 @@ def get_base_properties():
         },
         'self': {
             'type': 'string',
-            'description': '(READ-ONLY)'
+            'readOnly': True,
+            'description': _('An image self url'),
         },
         'file': {
             'type': 'string',
-            'description': '(READ-ONLY)'
+            'readOnly': True,
+            'description': _('An image file url'),
         },
         'schema': {
             'type': 'string',
-            'description': '(READ-ONLY)'
+            'readOnly': True,
+            'description': _('An image schema url'),
         },
         'locations': {
             'type': 'array',
