@@ -29,12 +29,11 @@ from glance.common import exception
 from glance.common import wsgi
 import glance.db
 import glance.gateway
-from glance import i18n
+from glance.i18n import _
 import glance.notifier
 import glance.schema
 
 LOG = logging.getLogger(__name__)
-_ = i18n._
 
 
 class ResourceTypeController(object):
@@ -230,14 +229,15 @@ def _get_base_properties():
         },
         "created_at": {
             "type": "string",
-            "description": _("Date and time of resource type association"
-                             " (READ-ONLY)"),
+            "readOnly": True,
+            "description": _("Date and time of resource type association"),
             "format": "date-time"
         },
         "updated_at": {
             "type": "string",
+            "readOnly": True,
             "description": _("Date and time of the last resource type "
-                             "association modification (READ-ONLY)"),
+                             "association modification"),
             "format": "date-time"
         }
     }
