@@ -28,14 +28,11 @@ from glance.common import exception
 from glance.common import wsgi
 from glance.common import wsme_utils
 import glance.db
-from glance import i18n
+from glance.i18n import _
 import glance.notifier
 import glance.schema
 
 LOG = logging.getLogger(__name__)
-_ = i18n._
-_LE = i18n._LE
-_LI = i18n._LI
 
 CONF = cfg.CONF
 
@@ -197,14 +194,14 @@ def _get_base_properties():
         },
         "created_at": {
             "type": "string",
-            "description": _("Date and time of tag creation"
-                             " (READ-ONLY)"),
+            "readOnly": True,
+            "description": _("Date and time of tag creation"),
             "format": "date-time"
         },
         "updated_at": {
             "type": "string",
-            "description": _("Date and time of the last tag modification"
-                             " (READ-ONLY)"),
+            "readOnly": True,
+            "description": _("Date and time of the last tag modification"),
             "format": "date-time"
         }
     }
