@@ -16,12 +16,13 @@
 
 import copy
 
+import debtcollector
 import glance_store
 from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_serialization.jsonutils as json
 from oslo_utils import encodeutils
-from oslo_utils import timeutils
+from oslo_utils import uuidutils
 import six
 import six.moves.urllib.parse as urlparse
 import webob.exc
@@ -29,21 +30,27 @@ import webob.exc
 from glance.api import common
 from glance.api import policy
 from glance.common import exception
-from glance.common import utils
+from glance.common import timeutils
 from glance.common import wsgi
 import glance.db
 import glance.gateway
-from glance import i18n
+from glance.i18n import _, _LW
 import glance.notifier
 import glance.schema
 
 LOG = logging.getLogger(__name__)
-_ = i18n._
-_LW = i18n._LW
 
 CONF = cfg.CONF
 CONF.import_opt('task_time_to_live', 'glance.common.config', group='task')
 
+_DEPRECATION_MESSAGE = ("The task API is being deprecated and "
+                        "it will be superseded by the new image import "
+                        "API. Please refer to this link for more "
+                        "information about the aforementioned process: "
+                        "https://specs.openstack.org/openstack/glance-specs/"
+                        "specs/mitaka/approved/image-import/"
+                        "image-import-refactor.html")
+
 
 class TasksController(object):
     """Manages operations on tasks."""
@@ -57,6 +64,7 @@ class TasksController(object):
         self.gateway = glance.gateway.Gateway(self.db_api, self.store_api,
                                               self.notifier, self.policy)
 
+    @debtcollector.removals.remove(message=_DEPRECATION_MESSAGE)
     def create(self, req, task):
         task_factory = self.gateway.get_task_factory(req.context)
         executor_factory = self.gateway.get_task_executor_factory(req.context)
@@ -76,6 +84,7 @@ class TasksController(object):
             raise webob.exc.HTTPForbidden(explanation=e.msg)
         return new_task
 
+    @debtcollector.removals.remove(message=_DEPRECATION_MESSAGE)
     def index(self, req, marker=None, limit=None, sort_key='created_at',
               sort_dir='desc', filters=None):
         result = {}
@@ -103,6 +112,7 @@ class TasksController(object):
         result['tasks'] = tasks
         return result
 
+    @debtcollector.removals.remove(message=_DEPRECATION_MESSAGE)
     def get(self, req, task_id):
         try:
             task_repo = self.gateway.get_task_repo(req.context)
@@ -122,6 +132,7 @@ class TasksController(object):
             raise webob.exc.HTTPForbidden(explanation=e.msg)
         return task
 
+    @debtcollector.removals.remove(message=_DEPRECATION_MESSAGE)
     def delete(self, req, task_id):
         msg = (_("This operation is currently not permitted on Glance Tasks. "
                  "They are auto deleted after reaching the time based on "
@@ -164,7 +175,7 @@ class RequestDeserializer(wsgi.JSONRequestDeserializer):
         return filters
 
     def _validate_marker(self, marker):
-        if marker and not utils.is_uuid_like(marker):
+        if marker and not uuidutils.is_uuid_like(marker):
             msg = _('Invalid marker format')
             raise webob.exc.HTTPBadRequest(explanation=msg)
         return marker
@@ -363,8 +374,14 @@ _TASK_SCHEMA = {
         "description": _("Datetime when this resource was updated"),
         "type": "string"
     },
-    'self': {'type': 'string'},
-    'schema': {'type': 'string'}
+    'self': {
+        'readOnly': True,
+        'type': 'string'
+    },
+    'schema': {
+        'readOnly': True,
+        'type': 'string'
+    }
 }
 
 
