@@ -15,17 +15,15 @@
 
 from oslo_config import cfg
 from oslo_serialization import jsonutils
-import six
 from six.moves import http_client
 import webob.dec
 
 from glance.common import wsgi
-from glance import i18n
+from glance.i18n import _
 
-_ = i18n._
 
 versions_opts = [
-    cfg.StrOpt('public_endpoint', default=None,
+    cfg.StrOpt('public_endpoint',
                help=_('Public url to use for versions endpoint. The default '
                       'is None, which will use the request\'s host_url '
                       'attribute to populate the URL base. If Glance is '
@@ -57,9 +55,6 @@ class Controller(object):
             }
 
         version_objs = []
-        if CONF.enable_v3_api:
-            version_objs.append(
-                build_version_object(3.0, 'v3', 'EXPERIMENTAL'))
         if CONF.enable_v2_api:
             version_objs.extend([
                 build_version_object(2.3, 'v2', 'CURRENT'),
@@ -77,10 +72,7 @@ class Controller(object):
         response = webob.Response(request=req,
                                   status=status,
                                   content_type='application/json')
-        json = jsonutils.dumps(dict(versions=version_objs))
-        if six.PY3:
-            json = json.encode('utf-8')
-        response.body = json
+        response.body = jsonutils.dump_as_bytes(dict(versions=version_objs))
         return response
 
     @webob.dec.wsgify(RequestClass=wsgi.Request)
