@@ -33,13 +33,10 @@ from taskflow.types import failure
 from glance.common import exception
 from glance.common.scripts.image_import import main as image_import
 from glance.common.scripts import utils as script_utils
-from glance import i18n
+from glance.i18n import _, _LE, _LI
 
 
 LOG = logging.getLogger(__name__)
-_ = i18n._
-_LE = i18n._LE
-_LI = i18n._LI
 
 
 CONF = cfg.CONF
@@ -68,7 +65,7 @@ class _CreateImage(task.Task):
             self.image_repo, self.image_factory,
             task_input.get('image_properties'), self.task_id)
 
-        LOG.debug("Task %(task_id)s created image %(image_id)s" %
+        LOG.debug("Task %(task_id)s created image %(image_id)s",
                   {'task_id': task.task_id, 'image_id': image.image_id})
         return image.image_id
 
@@ -117,7 +114,8 @@ class _ImportToFS(task.Task):
         backend.register_opts(conf)
         conf.set_override('filesystem_store_datadir',
                           CONF.task.work_dir,
-                          group='glance_store')
+                          group='glance_store',
+                          enforce_type=True)
 
         # NOTE(flaper87): Do not even try to judge me for this... :(
         # With the glance_store refactor, this code will change, until
@@ -159,9 +157,10 @@ class _ImportToFS(task.Task):
                                            log_errors=putils.LOG_ALL_ERRORS)
         except OSError as exc:
             with excutils.save_and_reraise_exception():
+                exc_message = encodeutils.exception_to_unicode(exc)
                 msg = (_LE('Failed to execute security checks on the image '
                            '%(task_id)s: %(exc)s') %
-                       {'task_id': self.task_id, 'exc': exc.message})
+                       {'task_id': self.task_id, 'exc': exc_message})
                 LOG.error(msg)
 
         metadata = json.loads(stdout)
@@ -373,7 +372,7 @@ class _CompleteTask(task.Task):
         finally:
             self.task_repo.save(task)
 
-        LOG.info(_LI("%(task_id)s of %(task_type)s completed") %
+        LOG.info(_LI("%(task_id)s of %(task_type)s completed"),
                  {'task_id': self.task_id, 'task_type': self.task_type})
 
 
@@ -386,7 +385,8 @@ def _get_import_flows(**kwargs):
     # Future patches will keep using NamedExtensionManager but they'll
     # rely on a config option to control this process.
     extensions = named.NamedExtensionManager('glance.flows.import',
-                                             names=['convert',
+                                             names=['ovf_process',
+                                                    'convert',
                                                     'introspect'],
                                              name_order=True,
                                              invoke_on_load=True,
