@@ -21,20 +21,16 @@ from oslo_config import cfg
 from taskflow.patterns import linear_flow as lf
 from taskflow import task
 
-from glance import i18n
+from glance.i18n import _, _LW
 
-_ = i18n._
-_LI = i18n._LI
-_LE = i18n._LE
-_LW = i18n._LW
 LOG = logging.getLogger(__name__)
 
 convert_task_opts = [
     cfg.StrOpt('conversion_format',
-               default=None,
                choices=('qcow2', 'raw', 'vmdk'),
                help=_("The format to which images will be automatically "
-                      "converted.")),
+                      "converted. When using the RBD backend, this should be "
+                      "set to 'raw'")),
 ]
 
 CONF = cfg.CONF
