@@ -13,22 +13,21 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import contextlib
-
 import futurist
 from oslo_config import cfg
 from oslo_log import log as logging
+from oslo_utils import encodeutils
 from oslo_utils import excutils
+from six.moves import urllib
 from stevedore import driver
 from taskflow import engines
 from taskflow.listeners import logging as llistener
 
 import glance.async
+from glance.common import exception
 from glance.common.scripts import utils as script_utils
-from glance import i18n
+from glance.i18n import _, _LE
 
-_ = i18n._
-_LE = i18n._LE
 LOG = logging.getLogger(__name__)
 
 _deprecated_opt = cfg.DeprecatedOpt('eventlet_executor_pool_size',
@@ -60,26 +59,22 @@ class TaskExecutor(glance.async.TaskExecutor):
         self.task_repo = task_repo
         self.image_repo = image_repo
         self.image_factory = image_factory
-        self.engine_conf = {
-            'engine': CONF.taskflow_executor.engine_mode,
-        }
-        self.engine_kwargs = {}
-        if CONF.taskflow_executor.engine_mode == 'parallel':
-            self.engine_kwargs['max_workers'] = (
-                CONF.taskflow_executor.max_workers)
         super(TaskExecutor, self).__init__(context, task_repo, image_repo,
                                            image_factory)
 
-    @contextlib.contextmanager
-    def _executor(self):
+    @staticmethod
+    def _fetch_an_executor():
         if CONF.taskflow_executor.engine_mode != 'parallel':
-            yield None
+            return None
         else:
             max_workers = CONF.taskflow_executor.max_workers
             try:
-                yield futurist.GreenThreadPoolExecutor(max_workers=max_workers)
+                return futurist.GreenThreadPoolExecutor(
+                    max_workers=max_workers)
             except RuntimeError:
-                yield futurist.ThreadPoolExecutor(max_workers=max_workers)
+                # NOTE(harlowja): I guess eventlet isn't being made
+                # useable, well just use native threads then (or try to).
+                return futurist.ThreadPoolExecutor(max_workers=max_workers)
 
     def _get_flow(self, task):
         try:
@@ -100,14 +95,28 @@ class TaskExecutor(glance.async.TaskExecutor):
             return driver.DriverManager('glance.flows', task.type,
                                         invoke_on_load=True,
                                         invoke_kwds=kwds).driver
+        except urllib.error.URLError as exc:
+            raise exception.ImportTaskError(message=exc.reason)
+        except exception.BadStoreUri as exc:
+            raise exception.ImportTaskError(message=exc.msg)
         except RuntimeError:
             raise NotImplementedError()
 
+    def begin_processing(self, task_id):
+        try:
+            super(TaskExecutor, self).begin_processing(task_id)
+        except exception.ImportTaskError as exc:
+            LOG.error(_LE('Failed to execute task %(task_id)s: %(exc)s') %
+                      {'task_id': task_id, 'exc': exc.msg})
+            task = self.task_repo.get(task_id)
+            task.fail(exc.msg)
+            self.task_repo.save(task)
+
     def _run(self, task_id, task_type):
         LOG.debug('Taskflow executor picked up the execution of task ID '
                   '%(task_id)s of task type '
-                  '%(task_type)s' % {'task_id': task_id,
-                                     'task_type': task_type})
+                  '%(task_type)s', {'task_id': task_id,
+                                    'task_type': task_type})
 
         task = script_utils.get_task(self.task_repo, task_id)
         if task is None:
@@ -117,18 +126,23 @@ class TaskExecutor(glance.async.TaskExecutor):
             return
 
         flow = self._get_flow(task)
-
+        executor = self._fetch_an_executor()
         try:
-            with self._executor() as executor:
-                engine = engines.load(flow, self.engine_conf,
-                                      executor=executor, **self.engine_kwargs)
-                with llistener.DynamicLoggingListener(engine, log=LOG):
-                    engine.run()
+            engine = engines.load(
+                flow,
+                engine=CONF.taskflow_executor.engine_mode, executor=executor,
+                max_workers=CONF.taskflow_executor.max_workers)
+            with llistener.DynamicLoggingListener(engine, log=LOG):
+                engine.run()
         except Exception as exc:
             with excutils.save_and_reraise_exception():
                 LOG.error(_LE('Failed to execute task %(task_id)s: %(exc)s') %
-                          {'task_id': task_id, 'exc': exc.message})
+                          {'task_id': task_id,
+                           'exc': encodeutils.exception_to_unicode(exc)})
                 # TODO(sabari): Check for specific exceptions and update the
                 # task failure message.
                 task.fail(_('Task failed due to Internal Error'))
                 self.task_repo.save(task)
+        finally:
+            if executor is not None:
+                executor.shutdown()
