@@ -29,6 +29,7 @@ from __future__ import print_function
 
 import os
 import sys
+import time
 
 # If ../glance/__init__.py exists, add ../ to Python search path, so that
 # it will override what happens to be installed in /usr/(local/)lib/python...
@@ -46,15 +47,15 @@ import six
 
 from glance.common import config
 from glance.common import exception
+from glance import context
 from glance.db import migration as db_migration
 from glance.db.sqlalchemy import api as db_api
 from glance.db.sqlalchemy import metadata
-from glance import i18n
+from glance.i18n import _
 
 
 CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
-_ = i18n._
 
 
 # Decorators for actions
@@ -87,6 +88,10 @@ class DbCommands(object):
     @args('--version', metavar='<version>', help='Database version')
     def downgrade(self, version=None):
         """Downgrade the database's migration level"""
+        print("Warning: DB downgrade is deprecated and will be removed in N "
+              "release. Users should make a full database backup of the "
+              "production data before attempting any upgrade.",
+              file=sys.stderr)
         migration.db_sync(db_api.get_engine(),
                           db_migration.MIGRATE_REPO_PATH,
                           version)
@@ -146,6 +151,23 @@ class DbCommands(object):
         metadata.db_export_metadefs(db_api.get_engine(),
                                     path)
 
+    @args('--age_in_days', type=int,
+          help='Purge deleted rows older than age in days')
+    @args('--max_rows', type=int,
+          help='Limit number of records to delete')
+    def purge(self, age_in_days=30, max_rows=100):
+        """Purge deleted rows older than a given age from glance tables."""
+        age_in_days = int(age_in_days)
+        max_rows = int(max_rows)
+        if age_in_days <= 0:
+            sys.exit(_("Must supply a positive, non-zero value for age."))
+        if age_in_days >= (int(time.time()) / 86400):
+            sys.exit(_("Maximal age is count of days since epoch."))
+        if max_rows < 1:
+            sys.exit(_("Minimal rows limit is 1."))
+        ctx = context.get_admin_context(show_deleted=True)
+        db_api.purge_deleted_rows(ctx, age_in_days, max_rows)
+
 
 class DbLegacyCommands(object):
     """Class for managing the db using legacy commands"""
@@ -160,6 +182,10 @@ class DbLegacyCommands(object):
         self.command_object.upgrade(CONF.command.version)
 
     def downgrade(self, version=None):
+        print("Warning: DB downgrade is deprecated and will be removed in N "
+              "release. Users should make a full database backup of the "
+              "production data before attempting any upgrade.",
+              file=sys.stderr)
         self.command_object.downgrade(CONF.command.version)
 
     def version_control(self, version=None):
@@ -305,6 +331,7 @@ def main():
         cfg_files.extend(cfg.find_config_files(project='glance',
                                                prog='glance-manage'))
         config.parse_args(default_config_files=cfg_files)
+        config.set_config_defaults()
         logging.setup(CONF, 'glance')
     except RuntimeError as e:
         sys.exit("ERROR: %s" % e)
