@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 # Copyright 2011 OpenStack Foundation
 # All Rights Reserved.
 #
@@ -23,18 +21,15 @@ import logging
 import logging.config
 import logging.handlers
 import os
-import tempfile
 
-from oslo_concurrency import lockutils
 from oslo_config import cfg
+from oslo_middleware import cors
 from oslo_policy import policy
 from paste import deploy
 
-from glance import i18n
+from glance.i18n import _
 from glance.version import version_info as version
 
-_ = i18n._
-
 paste_deploy_opts = [
     cfg.StrOpt('flavor',
                help=_('Partial name of a pipeline in your paste configuration '
@@ -47,7 +42,7 @@ paste_deploy_opts = [
 ]
 image_format_opts = [
     cfg.ListOpt('container_formats',
-                default=['ami', 'ari', 'aki', 'bare', 'ovf', 'ova'],
+                default=['ami', 'ari', 'aki', 'bare', 'ovf', 'ova', 'docker'],
                 help=_("Supported values for the 'container_format' "
                        "image attribute"),
                 deprecated_opts=[cfg.DeprecatedOpt('container_formats',
@@ -72,7 +67,6 @@ task_opts = [
                help=_("Specifies which task executor to be used to run the "
                       "task scripts.")),
     cfg.StrOpt('work_dir',
-               default=None,
                help=_('Work dir for asynchronous task operations. '
                       'The directory set here will be used to operate over '
                       'images - normally before they are imported in the '
@@ -129,7 +123,9 @@ common_opts = [
                        'in the \'direct_url\' meta-data field. '
                        'Revealing storage location can '
                        'be a security risk, so use this setting with '
-                       'caution!  The overrides show_image_direct_url.')),
+                       'caution! '
+                       'Setting this to true overrides the '
+                       'show_image_direct_url option.')),
     cfg.IntOpt('image_size_cap', default=1099511627776,
                max=9223372036854775808,
                help=_("Maximum size of image a user can upload in bytes. "
@@ -151,8 +147,6 @@ common_opts = [
                 help=_("Deploy the v1 OpenStack Images API.")),
     cfg.BoolOpt('enable_v2_api', default=True,
                 help=_("Deploy the v2 OpenStack Images API.")),
-    cfg.BoolOpt('enable_v3_api', default=False,
-                help=_("Deploy the v3 OpenStack Objects API.")),
     cfg.BoolOpt('enable_v1_registry', default=True,
                 help=_("Deploy the v1 OpenStack Registry API.")),
     cfg.BoolOpt('enable_v2_registry', default=True,
@@ -160,9 +154,9 @@ common_opts = [
     cfg.StrOpt('pydev_worker_debug_host',
                help=_('The hostname/IP of the pydev process listening for '
                       'debug connections')),
-    cfg.IntOpt('pydev_worker_debug_port', default=5678, min=1, max=65535,
-               help=_('The port on which a pydev process is listening for '
-                      'connections.')),
+    cfg.PortOpt('pydev_worker_debug_port', default=5678,
+                help=_('The port on which a pydev process is listening for '
+                       'connections.')),
     cfg.StrOpt('metadata_encryption_key', secret=True,
                help=_('AES key for encrypting store \'location\' metadata. '
                       'This includes, if used, Swift or S3 credentials. '
@@ -171,7 +165,7 @@ common_opts = [
     cfg.StrOpt('digest_algorithm', default='sha256',
                help=_('Digest algorithm which will be used for digital '
                       'signature. Use the command "openssl list-message-'
-                      'digest-algorithms" to get the available algorithms'
+                      'digest-algorithms" to get the available algorithms '
                       'supported by the version of OpenSSL on the platform.'
                       ' Examples are "sha1", "sha256", "sha512", etc.')),
 ]
@@ -185,9 +179,6 @@ policy.Enforcer(CONF)
 
 
 def parse_args(args=None, usage=None, default_config_files=None):
-    if "OSLO_LOCK_PATH" not in os.environ:
-        lockutils.set_defaults(tempfile.gettempdir())
-
     CONF(args=args,
          project='glance',
          version=version.cached_version_string(),
@@ -250,7 +241,7 @@ def load_paste_app(app_name, flavor=None, conf_file=None):
     :param flavor: name of the variant of the application to load
     :param conf_file: path to the paste config file
 
-    :raises RuntimeError when config file cannot be located or application
+    :raises: RuntimeError when config file cannot be located or application
             cannot be loaded from config file
     """
     # append the deployment flavor to the application name,
@@ -280,3 +271,37 @@ def load_paste_app(app_name, flavor=None, conf_file=None):
                                     'e': e})
         logger.error(msg)
         raise RuntimeError(msg)
+
+
+def set_config_defaults():
+    """This method updates all configuration default values."""
+    set_cors_middleware_defaults()
+
+
+def set_cors_middleware_defaults():
+    """Update default configuration options for oslo.middleware."""
+    # CORS Defaults
+    # TODO(krotscheck): Update with https://review.openstack.org/#/c/285368/
+    cfg.set_defaults(cors.CORS_OPTS,
+                     allow_headers=['Content-MD5',
+                                    'X-Image-Meta-Checksum',
+                                    'X-Storage-Token',
+                                    'Accept-Encoding',
+                                    'X-Auth-Token',
+                                    'X-Identity-Status',
+                                    'X-Roles',
+                                    'X-Service-Catalog',
+                                    'X-User-Id',
+                                    'X-Tenant-Id',
+                                    'X-OpenStack-Request-ID'],
+                     expose_headers=['X-Image-Meta-Checksum',
+                                     'X-Auth-Token',
+                                     'X-Subject-Token',
+                                     'X-Service-Token',
+                                     'X-OpenStack-Request-ID'],
+                     allow_methods=['GET',
+                                    'PUT',
+                                    'POST',
+                                    'DELETE',
+                                    'PATCH']
+                     )
