@@ -19,10 +19,7 @@ from oslo_config import cfg
 from oslo_log import log as logging
 import stevedore
 
-from glance import i18n
-
-_ = i18n._
-_LE = i18n._LE
+from glance.i18n import _, _LE
 
 location_strategy_opts = [
     cfg.StrOpt('location_strategy', default='location_order',
@@ -92,7 +89,7 @@ def get_ordered_locations(locations, **kwargs):
 
     :param locations: The original image location list.
     :param kwargs: Strategy-specific arguments for under layer strategy module.
-    :return: The image location list with strategy-specific order.
+    :returns: The image location list with strategy-specific order.
     """
     if not locations:
         return []
@@ -107,7 +104,7 @@ def choose_best_location(locations, **kwargs):
 
     :param locations: The original image location list.
     :param kwargs: Strategy-specific arguments for under layer strategy module.
-    :return: The best location from image location list.
+    :returns: The best location from image location list.
     """
     locations = get_ordered_locations(locations, **kwargs)
     if locations:
