@@ -12,7 +12,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from collections import OrderedDict
 import re
 
 from oslo_config import cfg
@@ -22,14 +21,10 @@ from six.moves import configparser
 
 import glance.api.policy
 from glance.common import exception
-from glance import i18n
+from glance.i18n import _, _LE
 
-# NOTE(bourke): The default dict_type is collections.OrderedDict in py27, but
-# we must set manually for compatibility with py26
-CONFIG = configparser.SafeConfigParser(dict_type=OrderedDict)
+CONFIG = configparser.SafeConfigParser()
 LOG = logging.getLogger(__name__)
-_ = i18n._
-_LE = i18n._LE
 
 property_opts = [
     cfg.StrOpt('property_protection_file',
