@@ -27,19 +27,14 @@ from glance.api.v2 import images as v2_api
 from glance.common import exception
 from glance.common.scripts import utils as script_utils
 from glance.common import store_utils
-from glance import i18n
-
+from glance.i18n import _, _LE, _LI, _LW
 
 LOG = logging.getLogger(__name__)
-_ = i18n._
-_LE = i18n._LE
-_LI = i18n._LI
-_LW = i18n._LW
 
 
 def run(t_id, context, task_repo, image_repo, image_factory):
     LOG.info(_LI('Task %(task_id)s beginning import '
-                 'execution.') % {'task_id': t_id})
+                 'execution.'), {'task_id': t_id})
     _execute(t_id, task_repo, image_repo, image_factory)
 
 
@@ -132,10 +127,9 @@ def create_image(image_repo, image_factory, image_properties, task_id):
         try:
             properties[key] = image_properties.pop(key)
         except KeyError:
-            msg = ("Task ID %(task_id)s: Ignoring property %(k)s for setting "
-                   "base properties while creating "
-                   "Image.") % {'task_id': task_id, 'k': key}
-            LOG.debug(msg)
+            LOG.debug("Task ID %(task_id)s: Ignoring property %(k)s for "
+                      "setting base properties while creating "
+                      "Image.", {'task_id': task_id, 'k': key})
 
     # NOTE: get the rest of the properties and pass them as
     # extra_properties for Image to be created with them.
@@ -151,7 +145,7 @@ def set_image_data(image, uri, task_id):
     data_iter = None
     try:
         LOG.info(_LI("Task %(task_id)s: Got image data uri %(data_uri)s to be "
-                 "imported") % {"data_uri": uri, "task_id": task_id})
+                 "imported"), {"data_uri": uri, "task_id": task_id})
         data_iter = script_utils.get_image_data_iter(uri)
         image.set_data(data_iter)
     except Exception as e:
@@ -160,8 +154,8 @@ def set_image_data(image, uri, task_id):
                      {"error": encodeutils.exception_to_unicode(e),
                       "task_id": task_id})
             LOG.info(_LI("Task %(task_id)s: Could not import image file"
-                         " %(image_data)s") % {"image_data": uri,
-                                               "task_id": task_id})
+                         " %(image_data)s"), {"image_data": uri,
+                                              "task_id": task_id})
     finally:
-        if isinstance(data_iter, file):
+        if hasattr(data_iter, 'close'):
             data_iter.close()
