@@ -26,12 +26,9 @@ from oslo_log import log as logging
 from six.moves import urllib
 
 from glance.common import exception
-from glance import i18n
-
+from glance.i18n import _, _LE
 
 LOG = logging.getLogger(__name__)
-_ = i18n._
-_LE = i18n._LE
 
 
 def get_task(task_repo, task_id):
@@ -97,9 +94,9 @@ def validate_location_uri(location):
     elif location.startswith(("file:///", "filesystem:///")):
         msg = _("File based imports are not allowed. Please use a non-local "
                 "source of image data.")
-        # NOTE: raise Exception and let the encompassing block save
-        # the error msg in the task.message.
-        raise StandardError(msg)
+        # NOTE: raise BadStoreUri and let the encompassing block save the error
+        # msg in the task.message.
+        raise exception.BadStoreUri(msg)
 
     else:
         # TODO(nikhil): add other supported uris
