@@ -12,16 +12,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from collections import OrderedDict
 from oslo_config import cfg
 from oslo_log import log as logging
 from six.moves import configparser
 
 from glance.common import exception
-from glance import i18n
-
-_ = i18n._
-_LE = i18n._LE
+from glance.i18n import _, _LE
 
 swift_opts = [
     cfg.StrOpt('default_swift_reference',
@@ -42,9 +38,7 @@ swift_opts = [
                       'configs.')),
 ]
 
-# NOTE(bourke): The default dict_type is collections.OrderedDict in py27, but
-# we must set manually for compatibility with py26
-CONFIG = configparser.SafeConfigParser(dict_type=OrderedDict)
+CONFIG = configparser.SafeConfigParser()
 LOG = logging.getLogger(__name__)
 
 
