@@ -22,16 +22,14 @@ from oslo_utils import importutils
 from wsme.rest import json
 
 from glance.api.v2.model.metadef_property_type import PropertyType
-from glance import artifacts as ga
-from glance.common.artifacts import serialization
 from glance.common import crypt
 from glance.common import exception
+from glance.common.glare import serialization
 from glance.common import location_strategy
 import glance.domain
 import glance.domain.proxy
-from glance import i18n
-
-_ = i18n._
+from glance import glare as ga
+from glance.i18n import _
 
 CONF = cfg.CONF
 CONF.import_opt('image_size_cap', 'glance.common.config')
@@ -163,8 +161,9 @@ class ImageRepo(object):
     def get(self, image_id):
         try:
             db_api_image = dict(self.db_api.image_get(self.context, image_id))
-            assert not db_api_image['deleted']
-        except (exception.ImageNotFound, exception.Forbidden, AssertionError):
+            if db_api_image['deleted']:
+                raise exception.ImageNotFound()
+        except (exception.ImageNotFound, exception.Forbidden):
             msg = _("No image found with ID %s") % image_id
             raise exception.ImageNotFound(msg)
         tags = self.db_api.image_tag_get_all(self.context, image_id)
@@ -253,7 +252,8 @@ class ImageRepo(object):
 
     def add(self, image):
         image_values = self._format_image_to_db(image)
-        if image_values['size'] > CONF.image_size_cap:
+        if (image_values['size'] is not None
+           and image_values['size'] > CONF.image_size_cap):
             raise exception.ImageSizeLimitExceeded
         # the updated_at value is not set in the _format_image_to_db
         # function since it is specific to image create
@@ -266,7 +266,8 @@ class ImageRepo(object):
 
     def save(self, image, from_state=None):
         image_values = self._format_image_to_db(image)
-        if image_values['size'] > CONF.image_size_cap:
+        if (image_values['size'] is not None
+           and image_values['size'] > CONF.image_size_cap):
             raise exception.ImageSizeLimitExceeded
         try:
             new_values = self.db_api.image_update(self.context,
@@ -282,10 +283,10 @@ class ImageRepo(object):
         image.updated_at = new_values['updated_at']
 
     def remove(self, image):
-        image_values = self._format_image_to_db(image)
         try:
             self.db_api.image_update(self.context, image.image_id,
-                                     image_values, purge_props=True)
+                                     {'status': image.status},
+                                     purge_props=True)
         except (exception.ImageNotFound, exception.Forbidden):
             msg = _("No image found with ID %s") % image.image_id
             raise exception.ImageNotFound(msg)
@@ -302,11 +303,6 @@ class ImageProxy(glance.domain.proxy.Image):
         self.image = image
         super(ImageProxy, self).__init__(image)
 
-    def get_member_repo(self):
-        member_repo = ImageMemberRepo(self.context, self.db_api,
-                                      self.image)
-        return member_repo
-
 
 class ImageMemberRepo(object):
 
