@@ -16,21 +16,18 @@
 
 import copy
 import functools
-from operator import itemgetter
 import uuid
 
 from oslo_log import log as logging
-from oslo_utils import timeutils
 import six
 
 from glance.common import exception
+from glance.common import timeutils
 from glance.common import utils
-from glance import i18n
+from glance.i18n import _, _LI, _LW
+
 
 LOG = logging.getLogger(__name__)
-_ = i18n._
-_LI = i18n._LI
-_LW = i18n._LW
 
 DATA = {
     'images': {},
@@ -60,12 +57,12 @@ def log_call(func):
     @functools.wraps(func)
     def wrapped(*args, **kwargs):
         LOG.info(_LI('Calling %(funcname)s: args=%(args)s, '
-                     'kwargs=%(kwargs)s') %
+                     'kwargs=%(kwargs)s'),
                  {"funcname": func.__name__,
                   "args": args,
                   "kwargs": kwargs})
         output = func(*args, **kwargs)
-        LOG.info(_LI('Returning %(funcname)s: %(output)s') %
+        LOG.info(_LI('Returning %(funcname)s: %(output)s'),
                  {"funcname": func.__name__,
                   "output": output})
         return output
@@ -130,7 +127,8 @@ def _image_property_format(image_id, name, value):
     }
 
 
-def _image_member_format(image_id, tenant_id, can_share, status='pending'):
+def _image_member_format(image_id, tenant_id, can_share, status='pending',
+                         deleted=False):
     dt = timeutils.utcnow()
     return {
         'id': str(uuid.uuid4()),
@@ -140,12 +138,13 @@ def _image_member_format(image_id, tenant_id, can_share, status='pending'):
         'status': status,
         'created_at': dt,
         'updated_at': dt,
+        'deleted': deleted,
     }
 
 
 def _pop_task_info_values(values):
     task_info_values = {}
-    for k, v in values.items():
+    for k, v in list(values.items()):
         if k in ['input', 'result', 'message']:
             values.pop(k)
             task_info_values[k] = v
@@ -298,6 +297,27 @@ def _filter_images(images, filters, context,
                 to_add = image.get(key) >= value
             elif k.endswith('_max'):
                 to_add = image.get(key) <= value
+            elif k in ['created_at', 'updated_at']:
+                attr_value = image.get(key)
+                operator, isotime = utils.split_filter_op(value)
+                parsed_time = timeutils.parse_isotime(isotime)
+                threshold = timeutils.normalize_time(parsed_time)
+                to_add = utils.evaluate_filter_op(attr_value, operator,
+                                                  threshold)
+            elif k in ['name', 'id', 'status',
+                       'container_format', 'disk_format']:
+                attr_value = image.get(key)
+                operator, list_value = utils.split_filter_op(value)
+                if operator == 'in':
+                    threshold = utils.split_filter_value_for_quotes(list_value)
+                    to_add = attr_value in threshold
+                elif operator == 'eq':
+                    to_add = (attr_value == list_value)
+                else:
+                    msg = (_("Unable to filter by unknown operator '%s'.")
+                           % operator)
+                    raise exception.InvalidFilterOperatorValue(msg)
+
             elif k != 'is_public' and image.get(k) is not None:
                 to_add = image.get(key) == value
             elif k == 'tags':
@@ -373,9 +393,9 @@ def _sort_images(images, sort_key, sort_dir):
         raise exception.Invalid(message='Number of sort dirs does not match '
                                         'the number of sort keys')
 
-    for key, dir in reversed(zip(sort_key, sort_dir)):
+    for key, dir in reversed(list(zip(sort_key, sort_dir))):
         reverse = dir == 'desc'
-        images.sort(key=itemgetter(key), reverse=reverse)
+        images.sort(key=lambda x: x[key] or '', reverse=reverse)
 
     return images
 
@@ -490,7 +510,7 @@ def image_member_count(context, image_id):
         raise exception.Invalid(msg)
 
     members = DATA['members']
-    return len(filter(lambda x: x['image_id'] == image_id, members))
+    return len([x for x in members if x['image_id'] == image_id])
 
 
 @log_call
@@ -498,7 +518,8 @@ def image_member_create(context, values):
     member = _image_member_format(values['image_id'],
                                   values['member'],
                                   values.get('can_share', False),
-                                  values.get('status', 'pending'))
+                                  values.get('status', 'pending'),
+                                  values.get('deleted', False))
     global DATA
     DATA['members'].append(member)
     return copy.deepcopy(member)
@@ -885,8 +906,7 @@ def task_update(context, task_id, values):
     try:
         task = DATA['tasks'][task_id]
     except KeyError:
-        msg = "No task found with ID %s" % task_id
-        LOG.debug(msg)
+        LOG.debug("No task found with ID %s", task_id)
         raise exception.TaskNotFound(task_id=task_id)
 
     task.update(task_values)
@@ -917,8 +937,7 @@ def _task_get(context, task_id, force_show_deleted=False):
         raise exception.TaskNotFound(task_id=task_id)
 
     if not _is_task_visible(context, task):
-        msg = "Forbidding request, task %s is not visible" % task_id
-        LOG.debug(msg)
+        LOG.debug("Forbidding request, task %s is not visible", task_id)
         msg = _("Forbidding request, task %s is not visible") % task_id
         raise exception.Forbidden(msg)
 
@@ -936,8 +955,7 @@ def task_delete(context, task_id):
         DATA['tasks'][task_id]['updated_at'] = timeutils.utcnow()
         return copy.deepcopy(DATA['tasks'][task_id])
     except KeyError:
-        msg = "No task found with ID %s" % task_id
-        LOG.debug(msg)
+        LOG.debug("No task found with ID %s", task_id)
         raise exception.TaskNotFound(task_id=task_id)
 
 
@@ -952,7 +970,7 @@ def task_get_all(context, filters=None, marker=None, limit=None,
     :param limit: maximum number of tasks to return
     :param sort_key: task attribute by which results should be sorted
     :param sort_dir: direction in which results should be sorted (asc, desc)
-    :return: tasks set
+    :returns: tasks set
     """
     filters = filters or {}
     tasks = DATA['tasks'].values()
@@ -1057,8 +1075,7 @@ def _task_info_update(task_id, values):
     try:
         task_info = DATA['task_info'][task_id]
     except KeyError:
-        msg = "No task info found with task id %s" % task_id
-        LOG.debug(msg)
+        LOG.debug("No task info found with task id %s", task_id)
         raise exception.TaskNotFound(task_id=task_id)
 
     task_info.update(values)
@@ -1102,9 +1119,8 @@ def metadef_namespace_create(context, values):
 
     for namespace in DATA['metadef_namespaces']:
         if namespace['namespace'] == namespace_name:
-            msg = ("Can not create the metadata definition namespace. "
-                   "Namespace=%s already exists.") % namespace_name
-            LOG.debug(msg)
+            LOG.debug("Can not create the metadata definition namespace. "
+                      "Namespace=%s already exists.", namespace_name)
             raise exception.MetadefDuplicateNamespace(
                 namespace_name=namespace_name)
 
@@ -1133,11 +1149,9 @@ def metadef_namespace_update(context, namespace_id, values):
     if namespace['namespace'] != values['namespace']:
         for db_namespace in DATA['metadef_namespaces']:
             if db_namespace['namespace'] == values['namespace']:
-                msg = ("Invalid update. It would result in a duplicate"
-                       " metadata definition namespace with the same"
-                       " name of %s"
-                       % values['namespace'])
-                LOG.debug(msg)
+                LOG.debug("Invalid update. It would result in a duplicate "
+                          "metadata definition namespace with the same "
+                          "name of %s", values['namespace'])
                 emsg = (_("Invalid update. It would result in a duplicate"
                           " metadata definition namespace with the same"
                           " name of %s")
@@ -1165,11 +1179,10 @@ def metadef_namespace_get_by_id(context, namespace_id):
         raise exception.MetadefNamespaceNotFound(msg)
 
     if not _is_namespace_visible(context, namespace):
-        msg = ("Forbidding request, metadata definition namespace=%s"
-               " is not visible.") % namespace.namespace
-        LOG.debug(msg)
-        emsg = _("Forbidding request, metadata definition namespace=%s"
-                 " is not visible.") % namespace.namespace
+        LOG.debug("Forbidding request, metadata definition namespace=%s "
+                  "is not visible.", namespace.namespace)
+        emsg = _("Forbidding request, metadata definition namespace=%s "
+                 "is not visible.") % namespace.namespace
         raise exception.MetadefForbidden(emsg)
 
     return namespace
@@ -1182,8 +1195,7 @@ def metadef_namespace_get(context, namespace_name):
         namespace = next(namespace for namespace in DATA['metadef_namespaces']
                          if namespace['namespace'] == namespace_name)
     except StopIteration:
-        msg = "No namespace found with name %s" % namespace_name
-        LOG.debug(msg)
+        LOG.debug("No namespace found with name %s", namespace_name)
         raise exception.MetadefNamespaceNotFound(
             namespace_name=namespace_name)
 
@@ -1273,10 +1285,9 @@ def metadef_object_get(context, namespace_name, object_name):
                 object['name'] == object_name):
             return object
     else:
-        msg = ("The metadata definition object with name=%(name)s"
-               " was not found in namespace=%(namespace_name)s."
-               % {'name': object_name, 'namespace_name': namespace_name})
-        LOG.debug(msg)
+        LOG.debug("The metadata definition object with name=%(name)s"
+                  " was not found in namespace=%(namespace_name)s.",
+                  {'name': object_name, 'namespace_name': namespace_name})
         raise exception.MetadefObjectNotFound(namespace_name=namespace_name,
                                               object_name=object_name)
 
@@ -1330,10 +1341,9 @@ def metadef_object_create(context, namespace_name, values):
     for object in DATA['metadef_objects']:
         if (object['name'] == object_name and
                 object['namespace_id'] == namespace['id']):
-            msg = ("A metadata definition object with name=%(name)s"
-                   " in namespace=%(namespace_name)s already exists."
-                   % {'name': object_name, 'namespace_name': namespace_name})
-            LOG.debug(msg)
+            LOG.debug("A metadata definition object with name=%(name)s "
+                      "in namespace=%(namespace_name)s already exists.",
+                      {'name': object_name, 'namespace_name': namespace_name})
             raise exception.MetadefDuplicateObject(
                 object_name=object_name, namespace_name=namespace_name)
 
@@ -1370,12 +1380,11 @@ def metadef_object_update(context, namespace_name, object_id, values):
         for db_object in DATA['metadef_objects']:
             if (db_object['name'] == values['name'] and
                     db_object['namespace_id'] == namespace['id']):
-                msg = ("Invalid update. It would result in a duplicate"
-                       " metadata definition object with same name=%(name)s "
-                       " in namespace=%(namespace_name)s."
-                       % {'name': object['name'],
-                          'namespace_name': namespace_name})
-                LOG.debug(msg)
+                LOG.debug("Invalid update. It would result in a duplicate "
+                          "metadata definition object with same name=%(name)s "
+                          "in namespace=%(namespace_name)s.",
+                          {'name': object['name'],
+                           'namespace_name': namespace_name})
                 emsg = (_("Invalid update. It would result in a duplicate"
                           " metadata definition object with the same"
                           " name=%(name)s "
@@ -1455,12 +1464,11 @@ def metadef_property_create(context, namespace_name, values):
     for property in DATA['metadef_properties']:
         if (property['name'] == property_name and
                 property['namespace_id'] == namespace['id']):
-            msg = ("Can not create metadata definition property. A property"
-                   " with name=%(name)s already exists in"
-                   " namespace=%(namespace_name)s."
-                   % {'name': property_name,
-                      'namespace_name': namespace_name})
-            LOG.debug(msg)
+            LOG.debug("Can not create metadata definition property. A property"
+                      " with name=%(name)s already exists in"
+                      " namespace=%(namespace_name)s.",
+                      {'name': property_name,
+                       'namespace_name': namespace_name})
             raise exception.MetadefDuplicateProperty(
                 property_name=property_name,
                 namespace_name=namespace_name)
@@ -1498,13 +1506,12 @@ def metadef_property_update(context, namespace_name, property_id, values):
         for db_property in DATA['metadef_properties']:
             if (db_property['name'] == values['name'] and
                     db_property['namespace_id'] == namespace['id']):
-                msg = ("Invalid update. It would result in a duplicate"
-                       " metadata definition property with the same"
-                       " name=%(name)s"
-                       " in namespace=%(namespace_name)s."
-                       % {'name': property['name'],
-                          'namespace_name': namespace_name})
-                LOG.debug(msg)
+                LOG.debug("Invalid update. It would result in a duplicate"
+                          " metadata definition property with the same"
+                          " name=%(name)s"
+                          " in namespace=%(namespace_name)s.",
+                          {'name': property['name'],
+                           'namespace_name': namespace_name})
                 emsg = (_("Invalid update. It would result in a duplicate"
                           " metadata definition property with the same"
                           " name=%(name)s"
@@ -1567,10 +1574,9 @@ def metadef_property_get(context, namespace_name, property_name):
                 property['name'] == property_name):
             return property
     else:
-        msg = ("No property found with name=%(name)s in"
-               " namespace=%(namespace_name)s "
-               % {'name': property_name, 'namespace_name': namespace_name})
-        LOG.debug(msg)
+        LOG.debug("No property found with name=%(name)s in"
+                  " namespace=%(namespace_name)s ",
+                  {'name': property_name, 'namespace_name': namespace_name})
         raise exception.MetadefPropertyNotFound(namespace_name=namespace_name,
                                                 property_name=property_name)
 
@@ -1634,8 +1640,7 @@ def metadef_resource_type_get(context, resource_type_name):
                              if resource_type['name'] ==
                              resource_type_name)
     except StopIteration:
-        msg = "No resource type found with name %s" % resource_type_name
-        LOG.debug(msg)
+        LOG.debug("No resource type found with name %s", resource_type_name)
         raise exception.MetadefResourceTypeNotFound(
             resource_type_name=resource_type_name)
 
@@ -1660,12 +1665,11 @@ def metadef_resource_type_association_create(context, namespace_name,
     for association in DATA['metadef_namespace_resource_types']:
         if (association['namespace_id'] == namespace['id'] and
                 association['resource_type'] == resource_type['id']):
-            msg = ("The metadata definition resource-type association of"
-                   " resource_type=%(resource_type_name)s to"
-                   " namespace=%(namespace_name)s, already exists."
-                   % {'resource_type_name': resource_type_name,
-                      'namespace_name': namespace_name})
-            LOG.debug(msg)
+            LOG.debug("The metadata definition resource-type association of"
+                      " resource_type=%(resource_type_name)s to"
+                      " namespace=%(namespace_name)s, already exists.",
+                      {'resource_type_name': resource_type_name,
+                       'namespace_name': namespace_name})
             raise exception.MetadefDuplicateResourceTypeAssociation(
                 resource_type_name=resource_type_name,
                 namespace_name=namespace_name)
@@ -1697,9 +1701,9 @@ def metadef_resource_type_association_get(context, namespace_name,
                 association['resource_type'] == resource_type['id']):
             return association
     else:
-        msg = ("No resource type association found associated with namespace "
-               "%s and resource type %s" % namespace_name, resource_type_name)
-        LOG.debug(msg)
+        LOG.debug("No resource type association found associated with "
+                  "namespace %s and resource type %s", namespace_name,
+                  resource_type_name)
         raise exception.MetadefResourceTypeAssociationNotFound(
             resource_type_name=resource_type_name,
             namespace_name=namespace_name)
@@ -1741,10 +1745,9 @@ def metadef_tag_get(context, namespace_name, name):
         if tag['namespace_id'] == namespace['id'] and tag['name'] == name:
             return tag
     else:
-        msg = ("The metadata definition tag with name=%(name)s"
-               " was not found in namespace=%(namespace_name)s."
-               % {'name': name, 'namespace_name': namespace_name})
-        LOG.debug(msg)
+        LOG.debug("The metadata definition tag with name=%(name)s"
+                  " was not found in namespace=%(namespace_name)s.",
+                  {'name': name, 'namespace_name': namespace_name})
         raise exception.MetadefTagNotFound(name=name,
                                            namespace_name=namespace_name)
 
@@ -1795,10 +1798,9 @@ def metadef_tag_create(context, namespace_name, values):
 
     for tag in DATA['metadef_tags']:
         if tag['name'] == tag_name and tag['namespace_id'] == namespace['id']:
-            msg = ("A metadata definition tag with name=%(name)s"
-                   " in namespace=%(namespace_name)s already exists."
-                   % {'name': tag_name, 'namespace_name': namespace_name})
-            LOG.debug(msg)
+            LOG.debug("A metadata definition tag with name=%(name)s"
+                      " in namespace=%(namespace_name)s already exists.",
+                      {'name': tag_name, 'namespace_name': namespace_name})
             raise exception.MetadefDuplicateTag(
                 name=tag_name, namespace_name=namespace_name)
 
@@ -1846,10 +1848,9 @@ def metadef_tag_create_tags(context, namespace_name, tag_list):
                 'The keys %s are not valid' % str(incorrect_keys))
 
         if tag_name in tag_name_list:
-            msg = ("A metadata definition tag with name=%(name)s"
-                   " in namespace=%(namespace_name)s already exists."
-                   % {'name': tag_name, 'namespace_name': namespace_name})
-            LOG.debug(msg)
+            LOG.debug("A metadata definition tag with name=%(name)s"
+                      " in namespace=%(namespace_name)s already exists.",
+                      {'name': tag_name, 'namespace_name': namespace_name})
             raise exception.MetadefDuplicateTag(
                 name=tag_name, namespace_name=namespace_name)
         else:
@@ -1879,12 +1880,11 @@ def metadef_tag_update(context, namespace_name, id, values):
         for db_tag in DATA['metadef_tags']:
             if (db_tag['name'] == values['name'] and
                     db_tag['namespace_id'] == namespace['id']):
-                msg = ("Invalid update. It would result in a duplicate"
-                       " metadata definition tag with same name=%(name)s "
-                       " in namespace=%(namespace_name)s."
-                       % {'name': tag['name'],
-                          'namespace_name': namespace_name})
-                LOG.debug(msg)
+                LOG.debug("Invalid update. It would result in a duplicate"
+                          " metadata definition tag with same name=%(name)s "
+                          " in namespace=%(namespace_name)s.",
+                          {'name': tag['name'],
+                           'namespace_name': namespace_name})
                 raise exception.MetadefDuplicateTag(
                     name=tag['name'], namespace_name=namespace_name)
 
@@ -2000,7 +2000,7 @@ def _artifact_get(context, artifact_id, type_name,
                  artifact['type_version'] != type_version)):
             raise KeyError
     except KeyError:
-        LOG.info(_LI('Could not find artifact %s') % artifact_id)
+        LOG.info(_LI('Could not find artifact %s'), artifact_id)
         raise exception.NotFound()
 
     if artifact['deleted_at']:
@@ -2123,9 +2123,8 @@ def _is_namespace_visible(context, namespace):
 
 def _check_namespace_visibility(context, namespace, namespace_name):
     if not _is_namespace_visible(context, namespace):
-        msg = ("Forbidding request, metadata definition namespace=%s"
-               " is not visible." % namespace_name)
-        LOG.debug(msg)
+        LOG.debug("Forbidding request, metadata definition namespace=%s "
+                  "is not visible.", namespace_name)
         emsg = _("Forbidding request, metadata definition namespace=%s"
                  " is not visible.") % namespace_name
         raise exception.MetadefForbidden(emsg)
