@@ -26,20 +26,16 @@ import re
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import encodeutils
-from oslo_utils import timeutils
 import six
 import sqlalchemy
 from sqlalchemy import and_
 from sqlalchemy.schema import MetaData
 from sqlalchemy.sql import select
 
-from glance import i18n
+from glance.common import timeutils
+from glance.i18n import _, _LE, _LI, _LW
 
 LOG = logging.getLogger(__name__)
-_ = i18n._
-_LE = i18n._LE
-_LW = i18n._LW
-_LI = i18n._LI
 
 metadata_opts = [
     cfg.StrOpt('metadata_source_path', default='/etc/glance/metadefs/',
@@ -212,7 +208,10 @@ def _populate_metadata(meta, metadata_path=None, merge=False,
             with open(file) as json_file:
                 metadata = json.load(json_file)
         except Exception as e:
-            LOG.error(encodeutils.exception_to_unicode(e))
+            LOG.error(_LE("Failed to parse json file %(file_path)s while "
+                          "populating metadata due to: %(error_msg)s"),
+                      {"file_path": file,
+                       "error_msg": encodeutils.exception_to_unicode(e)})
             continue
 
         values = {
@@ -450,7 +449,7 @@ def _export_data_to_file(meta, path):
                 json_file.write(json.dumps(values))
         except Exception as e:
             LOG.exception(encodeutils.exception_to_unicode(e))
-        LOG.info(_LI("Namespace %(namespace)s saved in %(file)s") % {
+        LOG.info(_LI("Namespace %(namespace)s saved in %(file)s"), {
             'namespace': namespace_file_name, 'file': file_name})
 
 
