@@ -22,16 +22,12 @@ from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import excutils
 from oslo_utils import importutils
-from oslo_utils import timeutils
 import six
 
 from glance.common import exception
-from glance import i18n
+from glance.common import timeutils
+from glance.i18n import _, _LE, _LI, _LW
 
-_ = i18n._
-_LE = i18n._LE
-_LI = i18n._LI
-_LW = i18n._LW
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 CONF.import_opt('task_executor', 'glance.common.config', group='task')
@@ -107,7 +103,7 @@ class Image(object):
         # can be retried.
         'queued': ('saving', 'active', 'deleted'),
         'saving': ('active', 'killed', 'deleted', 'queued'),
-        'active': ('queued', 'pending_delete', 'deleted', 'deactivated'),
+        'active': ('pending_delete', 'deleted', 'deactivated'),
         'killed': ('deleted',),
         'pending_delete': ('deleted',),
         'deleted': (),
@@ -136,7 +132,7 @@ class Image(object):
         self.tags = kwargs.pop('tags', [])
         if kwargs:
             message = _("__init__() got unexpected keyword argument '%s'")
-            raise TypeError(message % kwargs.keys()[0])
+            raise TypeError(message % list(kwargs.keys())[0])
 
     @property
     def status(self):
@@ -254,9 +250,8 @@ class Image(object):
             # Noop if already deactive
             pass
         else:
-            msg = ("Not allowed to deactivate image in status '%s'"
-                   % self.status)
-            LOG.debug(msg)
+            LOG.debug("Not allowed to deactivate image in status '%s'",
+                      self.status)
             msg = (_("Not allowed to deactivate image in status '%s'")
                    % self.status)
             raise exception.Forbidden(message=msg)
@@ -268,9 +263,8 @@ class Image(object):
             # Noop if already active
             pass
         else:
-            msg = ("Not allowed to reactivate image in status '%s'"
-                   % self.status)
-            LOG.debug(msg)
+            LOG.debug("Not allowed to reactivate image in status '%s'",
+                      self.status)
             msg = (_("Not allowed to reactivate image in status '%s'")
                    % self.status)
             raise exception.Forbidden(message=msg)
@@ -403,18 +397,16 @@ class Task(object):
     def _set_task_status(self, new_status):
         if self._validate_task_status_transition(self.status, new_status):
             self._status = new_status
-            log_msg = (_LI("Task [%(task_id)s] status changing from "
-                           "%(cur_status)s to %(new_status)s") %
-                       {'task_id': self.task_id, 'cur_status': self.status,
-                        'new_status': new_status})
-            LOG.info(log_msg)
+            LOG.info(_LI("Task [%(task_id)s] status changing from "
+                         "%(cur_status)s to %(new_status)s"),
+                     {'task_id': self.task_id, 'cur_status': self.status,
+                      'new_status': new_status})
             self._status = new_status
         else:
-            log_msg = (_LE("Task [%(task_id)s] status failed to change from "
-                           "%(cur_status)s to %(new_status)s") %
-                       {'task_id': self.task_id, 'cur_status': self.status,
-                        'new_status': new_status})
-            LOG.error(log_msg)
+            LOG.error(_LE("Task [%(task_id)s] status failed to change from "
+                          "%(cur_status)s to %(new_status)s"),
+                      {'task_id': self.task_id, 'cur_status': self.status,
+                       'new_status': new_status})
             raise exception.InvalidTaskStatusTransition(
                 cur_status=self.status,
                 new_status=new_status
@@ -477,8 +469,8 @@ class TaskFactory(object):
             created_at,
             updated_at,
             task_input,
-            kwargs.get('message'),
             kwargs.get('result'),
+            kwargs.get('message')
         )
 
 
@@ -509,7 +501,7 @@ class TaskExecutorFactory(object):
 
             executor_cls = ('glance.async.%s_executor.'
                             'TaskExecutor' % task_executor)
-            LOG.debug("Loading %s executor" % task_executor)
+            LOG.debug("Loading %s executor", task_executor)
             executor = importutils.import_class(executor_cls)
             return executor(context,
                             self.task_repo,
