@@ -16,6 +16,8 @@
 import collections
 import copy
 
+from cryptography import exceptions as crypto_exception
+import debtcollector
 import glance_store as store
 from oslo_config import cfg
 from oslo_log import log as logging
@@ -26,13 +28,9 @@ from glance.common import exception
 from glance.common import signature_utils
 from glance.common import utils
 import glance.domain.proxy
-from glance import i18n
+from glance.i18n import _, _LE, _LI
 
 
-_ = i18n._
-_LE = i18n._LE
-_LI = i18n._LI
-
 CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
@@ -48,11 +46,16 @@ class ImageRepoProxy(glance.domain.proxy.Repo):
                                              item_proxy_class=ImageProxy,
                                              item_proxy_kwargs=proxy_kwargs)
 
+        self.db_api = glance.db.get_api()
+
     def _set_acls(self, image):
         public = image.visibility == 'public'
         member_ids = []
         if image.locations and not public:
-            member_repo = image.get_member_repo()
+            member_repo = _get_member_repo_for_store(image,
+                                                     self.context,
+                                                     self.db_api,
+                                                     self.store_api)
             member_ids = [m.member_id for m in member_repo.list()]
         for location in image.locations:
             self.store_api.set_acls(location['url'], public=public,
@@ -70,6 +73,15 @@ class ImageRepoProxy(glance.domain.proxy.Repo):
         return result
 
 
+def _get_member_repo_for_store(image, context, db_api, store_api):
+        image_member_repo = glance.db.ImageMemberRepo(
+            context, db_api, image)
+        store_image_repo = glance.location.ImageMemberRepoProxy(
+            image_member_repo, image, context, store_api)
+
+        return store_image_repo
+
+
 def _check_location_uri(context, store_api, store_utils, uri):
     """Check if an image location is valid.
 
@@ -235,31 +247,38 @@ class StoreLocations(collections.MutableSequence):
                         [location])
 
     def __delitem__(self, i):
+        if isinstance(i, slice):
+            if i.step not in (None, 1):
+                raise NotImplementedError("slice with step")
+            self.__delslice__(i.start, i.stop)
+            return
         location = None
         try:
-            location = self.value.__getitem__(i)
+            location = self.value[i]
         except Exception:
-            return self.value.__delitem__(i)
+            del self.value[i]
+            return
         self.image_proxy.store_utils.delete_image_location_from_backend(
             self.image_proxy.context,
             self.image_proxy.image.image_id,
             location)
-        self.value.__delitem__(i)
+        del self.value[i]
 
     def __delslice__(self, i, j):
-        i = max(i, 0)
-        j = max(j, 0)
+        i = 0 if i is None else max(i, 0)
+        j = len(self) if j is None else max(j, 0)
         locations = []
         try:
-            locations = self.value.__getslice__(i, j)
+            locations = self.value[i:j]
         except Exception:
-            return self.value.__delslice__(i, j)
+            del self.value[i:j]
+            return
         for location in locations:
             self.image_proxy.store_utils.delete_image_location_from_backend(
                 self.image_proxy.context,
                 self.image_proxy.image.image_id,
                 location)
-            self.value.__delitem__(i)
+            del self.value[i]
 
     def __iadd__(self, other):
         self.extend(other)
@@ -280,6 +299,9 @@ class StoreLocations(collections.MutableSequence):
     def __cmp__(self, other):
         return cmp(self.value, self.__cast(other))
 
+    def __eq__(self, other):
+        return self.value == self.__cast(other)
+
     def __iter__(self):
         return iter(self.value)
 
@@ -310,20 +332,32 @@ def _locations_proxy(target, attr):
             raise exception.BadStoreUri(message=reason)
         ori_value = getattr(getattr(self, target), attr)
         if ori_value != value:
-            # NOTE(zhiyan): Enforced locations list was previously empty list.
-            if len(ori_value) > 0:
+            # NOTE(flwang): If all the URL of passed-in locations are same as
+            # current image locations, that means user would like to only
+            # update the metadata, not the URL.
+            ordered_value = sorted([loc['url'] for loc in value])
+            ordered_ori = sorted([loc['url'] for loc in ori_value])
+            if len(ori_value) > 0 and ordered_value != ordered_ori:
                 raise exception.Invalid(_('Original locations is not empty: '
                                           '%s') % ori_value)
-            # NOTE(zhiyan): Check locations are all valid.
-            for location in value:
-                _check_image_location(self.context,
-                                      self.store_api,
-                                      self.store_utils,
-                                      location)
-                location['status'] = 'active'
-                if _count_duplicated_locations(value, location) > 1:
-                    raise exception.DuplicateLocation(location=location['url'])
-            _set_image_size(self.context, getattr(self, target), value)
+            # NOTE(zhiyan): Check locations are all valid
+            # NOTE(flwang): If all the URL of passed-in locations are same as
+            # current image locations, then it's not necessary to verify those
+            # locations again. Otherwise, if there is any restricted scheme in
+            # existing locations. _check_image_location will fail.
+            if ordered_value != ordered_ori:
+                for loc in value:
+                    _check_image_location(self.context,
+                                          self.store_api,
+                                          self.store_utils,
+                                          loc)
+                    loc['status'] = 'active'
+                    if _count_duplicated_locations(value, loc) > 1:
+                        raise exception.DuplicateLocation(location=loc['url'])
+                _set_image_size(self.context, getattr(self, target), value)
+            else:
+                for loc in value:
+                    loc['status'] = 'active'
             return setattr(getattr(self, target), attr, list(value))
 
     def del_attr(self):
@@ -370,14 +404,49 @@ class ImageProxy(glance.domain.proxy.Image):
     def set_data(self, data, size=None):
         if size is None:
             size = 0  # NOTE(markwash): zero -> unknown size
+
+        # Create the verifier for signature verification (if correct properties
+        # are present)
+        if (signature_utils.should_create_verifier(
+                self.image.extra_properties)):
+            # NOTE(bpoulos): if creating verifier fails, exception will be
+            # raised
+            verifier = signature_utils.get_verifier(
+                self.context, self.image.extra_properties)
+        else:
+            verifier = None
+
         location, size, checksum, loc_meta = self.store_api.add_to_backend(
             CONF,
             self.image.image_id,
             utils.LimitingReader(utils.CooperativeReader(data),
                                  CONF.image_size_cap),
             size,
-            context=self.context)
+            context=self.context,
+            verifier=verifier)
 
+        self._verify_signature_if_needed(checksum)
+
+        # NOTE(bpoulos): if verification fails, exception will be raised
+        if verifier:
+            try:
+                verifier.verify()
+                LOG.info(_LI("Successfully verified signature for image %s"),
+                         self.image.image_id)
+            except crypto_exception.InvalidSignature:
+                raise exception.SignatureVerificationError(
+                    _('Signature verification failed')
+                )
+
+        self.image.locations = [{'url': location, 'metadata': loc_meta,
+                                 'status': 'active'}]
+        self.image.size = size
+        self.image.checksum = checksum
+        self.image.status = 'active'
+
+    @debtcollector.removals.remove(
+        message="This will be removed in the N cycle.")
+    def _verify_signature_if_needed(self, checksum):
         # Verify the signature (if correct properties are present)
         if (signature_utils.should_verify_signature(
                 self.image.extra_properties)):
@@ -385,15 +454,8 @@ class ImageProxy(glance.domain.proxy.Image):
             result = signature_utils.verify_signature(
                 self.context, checksum, self.image.extra_properties)
             if result:
-                msg = (_LI("Successfully verified signature for image "
-                           "%s") % self.image.image_id)
-                LOG.info(msg)
-
-        self.image.locations = [{'url': location, 'metadata': loc_meta,
-                                 'status': 'active'}]
-        self.image.size = size
-        self.image.checksum = checksum
-        self.image.status = 'active'
+                LOG.info(_LI("Successfully verified signature for image %s"),
+                         self.image.image_id)
 
     def get_data(self, offset=0, chunk_size=None):
         if not self.image.locations:
