@@ -17,7 +17,8 @@ __all__ = [
     'list_registry_opts',
     'list_scrubber_opts',
     'list_cache_opts',
-    'list_manage_opts'
+    'list_manage_opts',
+    'list_artifacts_opts'
 ]
 
 import copy
@@ -52,7 +53,6 @@ _api_opts = [
         glance.common.wsgi.bind_opts,
         glance.common.wsgi.eventlet_opts,
         glance.common.wsgi.socket_opts,
-        glance.common.wsgi.profiler_opts,
         glance.image_cache.drivers.sqlite.sqlite_opts,
         glance.image_cache.image_cache_opts,
         glance.notifier.notifier_opts,
@@ -67,6 +67,7 @@ _api_opts = [
      glance.async.taskflow_executor.taskflow_executor_opts),
     ('store_type_location_strategy',
      glance.common.location_strategy.store_type.store_type_opts),
+    ('profiler', glance.common.wsgi.profiler_opts),
     ('paste_deploy', glance.common.config.paste_deploy_opts)
 ]
 _registry_opts = [
@@ -76,6 +77,7 @@ _registry_opts = [
         glance.common.wsgi.bind_opts,
         glance.common.wsgi.socket_opts,
         glance.common.wsgi.eventlet_opts))),
+    ('profiler', glance.common.wsgi.profiler_opts),
     ('paste_deploy', glance.common.config.paste_deploy_opts)
 ]
 _scrubber_opts = [
@@ -84,6 +86,7 @@ _scrubber_opts = [
         glance.scrubber.scrubber_opts,
         glance.scrubber.scrubber_cmd_opts,
         glance.scrubber.scrubber_cmd_cli_opts,
+        glance.registry.client.registry_client_opts,
         glance.registry.client.registry_client_ctx_opts,
         glance.registry.registry_addr_opts))),
 ]
@@ -98,6 +101,17 @@ _cache_opts = [
 _manage_opts = [
     (None, [])
 ]
+_artifacts_opts = [
+    (None, list(itertools.chain(
+        glance.api.middleware.context.context_opts,
+        glance.api.versions.versions_opts,
+        glance.common.wsgi.bind_opts,
+        glance.common.wsgi.eventlet_opts,
+        glance.common.wsgi.socket_opts,
+        glance.common.wsgi.profiler_opts,
+        glance.notifier.notifier_opts))),
+    ('paste_deploy', glance.common.config.paste_deploy_opts)
+]
 
 
 def list_api_opts():
@@ -144,3 +158,8 @@ def list_cache_opts():
 def list_manage_opts():
     """Return a list of oslo_config options available in Glance manage."""
     return [(g, copy.deepcopy(o)) for g, o in _manage_opts]
+
+
+def list_artifacts_opts():
+    """Return a list of oslo_config options available in Glance artifacts"""
+    return [(g, copy.deepcopy(o)) for g, o in _artifacts_opts]
