@@ -21,14 +21,14 @@ the Glance Registry API
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
 from oslo_utils import excutils
+import six
 
 from glance.common.client import BaseClient
 from glance.common import crypt
-from glance import i18n
+from glance.i18n import _LE
 from glance.registry.api.v1 import images
 
 LOG = logging.getLogger(__name__)
-_LE = i18n._LE
 
 
 class RegistryClient(BaseClient):
@@ -114,18 +114,21 @@ class RegistryClient(BaseClient):
             kwargs['headers'] = kwargs.get('headers', {})
             kwargs['headers'].update(self.identity_headers or {})
             if self._passed_request_id:
-                kwargs['headers']['X-Openstack-Request-ID'] = (
-                    self._passed_request_id)
+                request_id = self._passed_request_id
+                if six.PY3 and isinstance(request_id, bytes):
+                    request_id = request_id.decode('utf-8')
+                kwargs['headers']['X-Openstack-Request-ID'] = request_id
             res = super(RegistryClient, self).do_request(method,
                                                          action,
                                                          **kwargs)
             status = res.status
             request_id = res.getheader('x-openstack-request-id')
-            msg = ("Registry request %(method)s %(action)s HTTP %(status)s"
-                   " request id %(request_id)s" %
-                   {'method': method, 'action': action,
-                    'status': status, 'request_id': request_id})
-            LOG.debug(msg)
+            if six.PY3 and isinstance(request_id, bytes):
+                request_id = request_id.decode('utf-8')
+            LOG.debug("Registry request %(method)s %(action)s HTTP %(status)s"
+                      " request id %(request_id)s",
+                      {'method': method, 'action': action,
+                       'status': status, 'request_id': request_id})
 
         except Exception as exc:
             with excutils.save_and_reraise_exception():
@@ -172,7 +175,7 @@ class RegistryClient(BaseClient):
 
         encrypted_metadata = self.encrypt_metadata(image_metadata['image'])
         image_metadata['image'] = encrypted_metadata
-        body = jsonutils.dumps(image_metadata)
+        body = jsonutils.dump_as_bytes(image_metadata)
 
         res = self.do_request("POST", "/images", body=body, headers=headers)
         # Registry returns a JSONified dict(image=image_info)
@@ -191,7 +194,7 @@ class RegistryClient(BaseClient):
         encrypted_metadata = self.encrypt_metadata(image_metadata['image'])
         image_metadata['image'] = encrypted_metadata
         image_metadata['from_state'] = from_state
-        body = jsonutils.dumps(image_metadata)
+        body = jsonutils.dump_as_bytes(image_metadata)
 
         headers = {
             'Content-Type': 'application/json',
@@ -235,7 +238,7 @@ class RegistryClient(BaseClient):
               'memberships' not in member_data):
             member_data = dict(memberships=[member_data])
 
-        body = jsonutils.dumps(member_data)
+        body = jsonutils.dump_as_bytes(member_data)
 
         headers = {'Content-Type': 'application/json', }
 
@@ -249,7 +252,8 @@ class RegistryClient(BaseClient):
         headers = {}
         # Build up a body if can_share is specified
         if can_share is not None:
-            body = jsonutils.dumps(dict(member=dict(can_share=can_share)))
+            body = jsonutils.dump_as_bytes(
+                dict(member=dict(can_share=can_share)))
             headers['Content-Type'] = 'application/json'
 
         url = "/images/%s/members/%s" % (image_id, member_id)
