@@ -27,16 +27,11 @@ from glance.common import crypt
 from glance.common import exception
 from glance import context
 import glance.db as db_api
-from glance import i18n
+from glance.i18n import _, _LE, _LI, _LW
 import glance.registry.client.v1.api as registry
 
 LOG = logging.getLogger(__name__)
 
-_ = i18n._
-_LI = i18n._LI
-_LW = i18n._LW
-_LE = i18n._LE
-
 scrubber_opts = [
     cfg.IntOpt('scrub_time', default=0,
                help=_('The amount of time in seconds to delay before '
@@ -235,12 +230,12 @@ class Daemon(object):
         LOG.debug("Running application")
         self.daemon_pool.spawn_n(application.run, self.event)
         eventlet.spawn_after(self.wakeup_time, self._run, application)
-        LOG.debug("Next run scheduled in %s seconds" % self.wakeup_time)
+        LOG.debug("Next run scheduled in %s seconds", self.wakeup_time)
 
 
 class Scrubber(object):
     def __init__(self, store_api):
-        LOG.info(_LI("Initializing scrubber with configuration: %s") %
+        LOG.info(_LI("Initializing scrubber with configuration: %s"),
                  six.text_type({'registry_host': CONF.registry_host,
                                 'registry_port': CONF.registry_port}))
 
@@ -298,7 +293,7 @@ class Scrubber(object):
         if len(delete_jobs) == 0:
             return
 
-        LOG.info(_LI("Scrubbing image %(id)s from %(count)d locations.") %
+        LOG.info(_LI("Scrubbing image %(id)s from %(count)d locations."),
                  {'id': image_id, 'count': len(delete_jobs)})
 
         success = True
@@ -312,7 +307,7 @@ class Scrubber(object):
             image = self.registry.get_image(image_id)
             if image['status'] == 'pending_delete':
                 self.registry.update_image(image_id, {'status': 'deleted'})
-            LOG.info(_LI("Image %s has been scrubbed successfully") % image_id)
+            LOG.info(_LI("Image %s has been scrubbed successfully"), image_id)
         else:
             LOG.warn(_LW("One or more image locations couldn't be scrubbed "
                          "from backend. Leaving image '%s' in 'pending_delete'"
@@ -322,20 +317,20 @@ class Scrubber(object):
         if CONF.metadata_encryption_key:
             uri = crypt.urlsafe_decrypt(CONF.metadata_encryption_key, uri)
         try:
-            LOG.debug("Scrubbing image %s from a location." % image_id)
+            LOG.debug("Scrubbing image %s from a location.", image_id)
             try:
                 self.store_api.delete_from_backend(uri, self.admin_context)
             except store_exceptions.NotFound:
                 LOG.info(_LI("Image location for image '%s' not found in "
                              "backend; Marking image location deleted in "
-                             "db.") % image_id)
+                             "db."), image_id)
 
             if loc_id != '-':
                 db_api.get_api().image_location_delete(self.admin_context,
                                                        image_id,
                                                        int(loc_id),
                                                        'deleted')
-            LOG.info(_LI("Image %s is scrubbed from a location.") % image_id)
+            LOG.info(_LI("Image %s is scrubbed from a location."), image_id)
         except Exception as e:
             LOG.error(_LE("Unable to scrub image %(id)s from a location. "
                           "Reason: %(exc)s ") %
