@@ -77,7 +77,6 @@ class Server(object):
         self.property_protection_file = ''
         self.enable_v1_api = True
         self.enable_v2_api = True
-        self.enable_v3_api = True
         self.enable_v1_registry = True
         self.enable_v2_registry = True
         self.needs_database = False
@@ -87,7 +86,7 @@ class Server(object):
         self.process_pid = None
         self.server_module = None
         self.stop_kill = False
-        self.use_user_token = False
+        self.use_user_token = True
         self.send_identity_credentials = False
 
     def write_conf(self, **kwargs):
@@ -348,7 +347,6 @@ show_multiple_locations = %(show_multiple_locations)s
 user_storage_quota = %(user_storage_quota)s
 enable_v1_api = %(enable_v1_api)s
 enable_v2_api = %(enable_v2_api)s
-enable_v3_api = %(enable_v3_api)s
 lock_path = %(lock_path)s
 property_protection_file = %(property_protection_file)s
 property_protection_rule_format = %(property_protection_rule_format)s
@@ -370,14 +368,21 @@ filesystem_store_datadir=%(image_dir)s
 default_store = %(default_store)s
 """
         self.paste_conf_base = """[pipeline:glance-api]
-pipeline = healthcheck versionnegotiation gzip unauthenticated-context rootapp
+pipeline =
+    cors
+    healthcheck
+    versionnegotiation
+    gzip
+    unauthenticated-context
+    rootapp
 
 [pipeline:glance-api-caching]
-pipeline = healthcheck versionnegotiation gzip unauthenticated-context
+pipeline = cors healthcheck versionnegotiation gzip unauthenticated-context
  cache rootapp
 
 [pipeline:glance-api-cachemanagement]
 pipeline =
+    cors
     healthcheck
     versionnegotiation
     gzip
@@ -387,17 +392,16 @@ pipeline =
     rootapp
 
 [pipeline:glance-api-fakeauth]
-pipeline = healthcheck versionnegotiation gzip fakeauth context rootapp
+pipeline = cors healthcheck versionnegotiation gzip fakeauth context rootapp
 
 [pipeline:glance-api-noauth]
-pipeline = healthcheck versionnegotiation gzip context rootapp
+pipeline = cors healthcheck versionnegotiation gzip context rootapp
 
 [composite:rootapp]
 paste.composite_factory = glance.api:root_app_factory
 /: apiversions
 /v1: apiv1app
 /v2: apiv2app
-/v3: apiv3app
 
 [app:apiversions]
 paste.app_factory = glance.api.versions:create_resource
@@ -408,9 +412,6 @@ paste.app_factory = glance.api.v1.router:API.factory
 [app:apiv2app]
 paste.app_factory = glance.api.v2.router:API.factory
 
-[app:apiv3app]
-paste.app_factory = glance.api.v3.router:API.factory
-
 [filter:healthcheck]
 paste.filter_factory = oslo_middleware:Healthcheck.factory
 backends = disable_by_file
@@ -439,6 +440,10 @@ paste.filter_factory =
 
 [filter:fakeauth]
 paste.filter_factory = glance.tests.utils:FakeAuthMiddleware.factory
+
+[filter:cors]
+paste.filter_factory = oslo_middleware.cors:filter_factory
+allowed_origin=http://valid.example.com
 """
 
 
@@ -824,7 +829,7 @@ class FunctionalTest(test_utils.BaseTestCase):
         :param expect_launch: Optional, true iff the server(s) are
                               expected to successfully start
         :param timeout: Optional, defaults to 30 seconds
-        :return: None if launch expectation is met, otherwise an
+        :returns: None if launch expectation is met, otherwise an
                  assertion message
         """
         now = datetime.datetime.now()
