@@ -20,11 +20,12 @@ import datetime
 import uuid
 
 import mock
-from oslo_utils import timeutils
 # NOTE(jokke): simplified transition to py3, behaves like py2 xrange
 from six.moves import range
+from six.moves import reduce
 
 from glance.common import exception
+from glance.common import timeutils
 from glance import context
 from glance.tests import functional
 import glance.tests.functional.db as db_tests
@@ -75,7 +76,7 @@ def build_task_fixture(**kwargs):
         'message': None,
         'expires_at': None,
         'created_at': default_datetime,
-        'updated_at': default_datetime
+        'updated_at': default_datetime,
     }
     task.update(kwargs)
     return task
@@ -488,6 +489,80 @@ class DriverTests(object):
                                            filters={'poo': 'bear'})
         self.assertEqual(0, len(images))
 
+    def test_image_get_all_with_filter_comparative_created_at(self):
+        anchor = timeutils.isotime(self.fixtures[0]['created_at'])
+        time_expr = 'lt:' + anchor
+
+        images = self.db_api.image_get_all(self.context,
+                                           filters={'created_at': time_expr})
+        self.assertEqual(0, len(images))
+
+    def test_image_get_all_with_filter_comparative_updated_at(self):
+        anchor = timeutils.isotime(self.fixtures[0]['updated_at'])
+        time_expr = 'lt:' + anchor
+
+        images = self.db_api.image_get_all(self.context,
+                                           filters={'updated_at': time_expr})
+        self.assertEqual(0, len(images))
+
+    def test_filter_image_by_invalid_operator(self):
+        self.assertRaises(exception.InvalidFilterOperatorValue,
+                          self.db_api.image_get_all,
+                          self.context, filters={'status': 'lala:active'})
+
+    def test_image_get_all_with_filter_in_status(self):
+        images = self.db_api.image_get_all(self.context,
+                                           filters={'status': 'in:active'})
+        self.assertEqual(3, len(images))
+
+    def test_image_get_all_with_filter_in_name(self):
+        data = 'in:%s' % self.fixtures[0]['name']
+        images = self.db_api.image_get_all(self.context,
+                                           filters={'name': data})
+        self.assertEqual(3, len(images))
+
+    def test_image_get_all_with_filter_in_container_format(self):
+        images = self.db_api.image_get_all(self.context,
+                                           filters={'container_format':
+                                                    'in:ami,bare,ovf'})
+        self.assertEqual(3, len(images))
+
+    def test_image_get_all_with_filter_in_disk_format(self):
+        images = self.db_api.image_get_all(self.context,
+                                           filters={'disk_format':
+                                                    'in:vhd'})
+        self.assertEqual(3, len(images))
+
+    def test_image_get_all_with_filter_in_id(self):
+        data = 'in:%s,%s' % (UUID1, UUID2)
+        images = self.db_api.image_get_all(self.context,
+                                           filters={'id': data})
+        self.assertEqual(2, len(images))
+
+    def test_image_get_all_with_quotes(self):
+        fixture = {'name': 'fake\\\"name'}
+        self.db_api.image_update(self.adm_context, UUID3, fixture)
+
+        fixture = {'name': 'fake,name'}
+        self.db_api.image_update(self.adm_context, UUID2, fixture)
+
+        fixture = {'name': 'fakename'}
+        self.db_api.image_update(self.adm_context, UUID1, fixture)
+
+        data = 'in:\"fake\\\"name\",fakename,\"fake,name\"'
+
+        images = self.db_api.image_get_all(self.context,
+                                           filters={'name': data})
+        self.assertEqual(3, len(images))
+
+    def test_image_get_all_with_invalid_quotes(self):
+        invalid_expr = ['in:\"name', 'in:\"name\"name', 'in:name\"dd\"',
+                        'in:na\"me', 'in:\"name\"\"name\"']
+        for expr in invalid_expr:
+            self.assertRaises(exception.InvalidParameterValue,
+                              self.db_api.image_get_all,
+                              self.context, filters={'name': expr})
+
     def test_image_get_all_size_min_max(self):
         images = self.db_api.image_get_all(self.context,
                                            filters={
@@ -530,6 +605,14 @@ class DriverTests(object):
         images = self.db_api.image_get_all(self.context, marker=UUID3)
         self.assertEqual(2, len(images))
 
+    def test_image_get_all_marker_with_size(self):
+        # Use sort_key=size to test BigInteger
+        images = self.db_api.image_get_all(self.context, sort_key=['size'],
+                                           marker=UUID3)
+        self.assertEqual(2, len(images))
+        self.assertEqual(17, images[0]['size'])
+        self.assertEqual(13, images[1]['size'])
+
     def test_image_get_all_marker_deleted(self):
         """Cannot specify a deleted image as a marker."""
         self.db_api.image_destroy(self.adm_context, UUID1)
@@ -1148,6 +1231,7 @@ class DriverTests(object):
             'image_id': UUID1,
             'can_share': False,
             'status': 'pending',
+            'deleted': False,
         }
         self.assertEqual(expected, actual)
 
@@ -1167,7 +1251,8 @@ class DriverTests(object):
         expected = {'member': TENANT1,
                     'image_id': UUID1,
                     'status': 'pending',
-                    'can_share': False}
+                    'can_share': False,
+                    'deleted': False}
         self.assertEqual(expected, member)
 
         member = self.db_api.image_member_update(self.context,
@@ -1181,7 +1266,8 @@ class DriverTests(object):
         expected = {'member': TENANT1,
                     'image_id': UUID1,
                     'status': 'pending',
-                    'can_share': True}
+                    'can_share': True,
+                    'deleted': False}
         self.assertEqual(expected, member)
 
         members = self.db_api.image_member_find(self.context,
@@ -1208,7 +1294,8 @@ class DriverTests(object):
         expected = {'member': TENANT1,
                     'image_id': UUID1,
                     'status': 'pending',
-                    'can_share': False}
+                    'can_share': False,
+                    'deleted': False}
         self.assertEqual(expected, member)
 
         member = self.db_api.image_member_update(self.context,
@@ -1222,7 +1309,8 @@ class DriverTests(object):
         expected = {'member': TENANT1,
                     'image_id': UUID1,
                     'status': 'accepted',
-                    'can_share': False}
+                    'can_share': False,
+                    'deleted': False}
         self.assertEqual(expected, member)
 
         members = self.db_api.image_member_find(self.context,
@@ -1712,7 +1800,7 @@ class TaskTests(test_utils.BaseTestCase):
         self.assertIsNone(task['deleted_at'])
         self.assertIsNone(task['expires_at'])
         self.assertEqual(task_values['created_at'], task['created_at'])
-        self.assertTrue(task['updated_at'] > task['created_at'])
+        self.assertGreater(task['updated_at'], task['created_at'])
 
     def test_task_update_with_all_task_info_null(self):
         self.context.tenant = str(uuid.uuid4())
@@ -1737,7 +1825,7 @@ class TaskTests(test_utils.BaseTestCase):
         self.assertIsNone(task['deleted_at'])
         self.assertIsNone(task['expires_at'])
         self.assertEqual(task_values['created_at'], task['created_at'])
-        self.assertTrue(task['updated_at'] > task['created_at'])
+        self.assertGreater(task['updated_at'], task['created_at'])
 
     def test_task_delete(self):
         task_values = build_task_fixture(owner=self.context.owner)
@@ -1771,6 +1859,62 @@ class TaskTests(test_utils.BaseTestCase):
         self.assertIsNotNone(del_task['deleted_at'])
 
 
+class DBPurgeTests(test_utils.BaseTestCase):
+
+    def setUp(self):
+        super(DBPurgeTests, self).setUp()
+        self.adm_context = context.get_admin_context(show_deleted=True)
+        self.db_api = db_tests.get_db(self.config)
+        db_tests.reset_db(self.db_api)
+        self.image_fixtures, self.task_fixtures = self.build_fixtures()
+        self.create_tasks(self.task_fixtures)
+        self.create_images(self.image_fixtures)
+
+    def build_fixtures(self):
+        dt1 = timeutils.utcnow() - datetime.timedelta(days=5)
+        dt2 = dt1 + datetime.timedelta(days=1)
+        dt3 = dt2 + datetime.timedelta(days=1)
+        fixtures = [
+            {
+                'created_at': dt1,
+                'updated_at': dt1,
+                'deleted_at': dt3,
+                'deleted': True,
+            },
+            {
+                'created_at': dt1,
+                'updated_at': dt2,
+                'deleted_at': timeutils.utcnow(),
+                'deleted': True,
+            },
+            {
+                'created_at': dt2,
+                'updated_at': dt2,
+                'deleted_at': None,
+                'deleted': False,
+            },
+        ]
+        return (
+            [build_image_fixture(**fixture) for fixture in fixtures],
+            [build_task_fixture(**fixture) for fixture in fixtures],
+        )
+
+    def create_images(self, images):
+        for fixture in images:
+            self.db_api.image_create(self.adm_context, fixture)
+
+    def create_tasks(self, tasks):
+        for fixture in tasks:
+            self.db_api.task_create(self.adm_context, fixture)
+
+    def test_db_purge(self):
+        self.db_api.purge_deleted_rows(self.adm_context, 1, 5)
+        images = self.db_api.image_get_all(self.adm_context)
+        self.assertEqual(len(images), 2)
+        tasks = self.db_api.task_get_all(self.adm_context)
+        self.assertEqual(len(tasks), 2)
+
+
 class TestVisibility(test_utils.BaseTestCase):
     def setUp(self):
         super(TestVisibility, self).setUp()
