@@ -20,11 +20,11 @@ from oslo_db import options
 from glance.common import exception
 import glance.db.sqlalchemy.api
 from glance.db.sqlalchemy import models as db_models
-from glance.db.sqlalchemy import models_artifacts as artifact_models
+from glance.db.sqlalchemy import models_glare as artifact_models
 from glance.db.sqlalchemy import models_metadef as metadef_models
 import glance.tests.functional.db as db_tests
 from glance.tests.functional.db import base
-from glance.tests.functional.db import base_artifacts
+from glance.tests.functional.db import base_glare
 from glance.tests.functional.db import base_metadef
 
 CONF = cfg.CONF
@@ -160,8 +160,17 @@ class TestSqlAlchemyQuota(base.DriverQuotaTests,
         self.addCleanup(db_tests.reset)
 
 
-class TestArtifacts(base_artifacts.ArtifactsTestDriver,
-                    base_artifacts.ArtifactTests):
+class TestDBPurge(base.DBPurgeTests,
+                  base.FunctionalInitWrapper):
+
+    def setUp(self):
+        db_tests.load(get_db, reset_db)
+        super(TestDBPurge, self).setUp()
+        self.addCleanup(db_tests.reset)
+
+
+class TestArtifacts(base_glare.ArtifactsTestDriver,
+                    base_glare.ArtifactTests):
     def setUp(self):
         db_tests.load(get_db, reset_db_artifacts)
         super(TestArtifacts, self).setUp()
