@@ -31,11 +31,6 @@ class TestApiVersions(functional.FunctionalTest):
 
         url = 'http://127.0.0.1:%d/v%%s/' % self.api_port
         versions = {'versions': [
-            {
-                'status': 'EXPERIMENTAL',
-                'id': 'v3.0',
-                'links': [{'href': url % '3', "rel": "self"}],
-            },
             {
                 'id': 'v2.3',
                 'status': 'CURRENT',
@@ -83,11 +78,6 @@ class TestApiVersions(functional.FunctionalTest):
 
         url = 'http://127.0.0.1:%d/v%%s/' % self.api_port
         versions = {'versions': [
-            {
-                'status': 'EXPERIMENTAL',
-                'id': 'v3.0',
-                'links': [{'href': url % '3', "rel": "self"}],
-            },
             {
                 'id': 'v2.3',
                 'status': 'CURRENT',
@@ -121,7 +111,6 @@ class TestApiVersions(functional.FunctionalTest):
     def test_v1_api_configuration(self):
         self.api_server.enable_v1_api = True
         self.api_server.enable_v2_api = False
-        self.api_server.enable_v3_api = False
         self.start_servers(**self.__dict__.copy())
 
         url = 'http://127.0.0.1:%d/v%%s/' % self.api_port
@@ -154,11 +143,6 @@ class TestApiPaths(functional.FunctionalTest):
 
         url = 'http://127.0.0.1:%d/v%%s/' % self.api_port
         versions = {'versions': [
-            {
-                'status': 'EXPERIMENTAL',
-                'id': 'v3.0',
-                'links': [{'href': url % '3', "rel": "self"}],
-            },
             {
                 'id': 'v2.3',
                 'status': 'CURRENT',
