@@ -13,12 +13,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import time
-
+import eventlet
 from oslo_serialization import jsonutils as json
-from oslo_utils import timeutils
 
 from glance.api.v2 import tasks
+from glance.common import timeutils
 from glance.tests.integration.v2 import base
 
 TENANT1 = '6838eb7b-6ded-434a-882c-b344c77fe8df'
@@ -83,7 +82,11 @@ class TestTasksApi(base.ApiTest):
                         break
 
             if wait:
-                time.sleep(0.05)
+                # Bug #1541487: we must give time to the server to execute the
+                # task, but the server is run in the same process than the
+                # test. Use eventlet to give the control to the pending server
+                # task.
+                eventlet.sleep(0.05)
                 continue
             else:
                 break
