@@ -163,7 +163,7 @@ class TestImportTask(test_utils.BaseTestCase):
             return ("", None)
 
         with mock.patch.object(script_utils, 'get_image_data_iter') as dmock:
-            dmock.return_value = six.BytesIO("TEST_IMAGE")
+            dmock.return_value = six.BytesIO(b"TEST_IMAGE")
 
             with mock.patch.object(processutils, 'execute') as exc_mock:
                 exc_mock.side_effect = fake_execute
