@@ -18,6 +18,7 @@ from six.moves import urllib
 
 import glance.common.exception as exception
 from glance.common.scripts.image_import import main as image_import_script
+from glance.common.scripts import utils
 from glance.common import store_utils
 
 import glance.tests.utils as test_utils
@@ -83,11 +84,14 @@ class TestImageImport(test_utils.BaseTestCase):
                                                           image_properties,
                                                           None))
 
-    def test_set_image_data_http(self):
+    @mock.patch.object(utils, 'get_image_data_iter')
+    def test_set_image_data_http(self, mock_image_iter):
         uri = 'http://www.example.com'
         image = mock.Mock()
-        self.assertEqual(None,
-                         image_import_script.set_image_data(image, uri, None))
+        mock_image_iter.return_value = test_utils.FakeHTTPResponse()
+        self.assertIsNone(image_import_script.set_image_data(image,
+                                                             uri,
+                                                             None))
 
     def test_set_image_data_http_error(self):
         uri = 'blahhttp://www.example.com'
