@@ -16,12 +16,14 @@
 
 import datetime
 import gettext
+import os
 import socket
 
 from babel import localedata
 import eventlet.patcher
 import fixtures
 import mock
+from oslo_concurrency import processutils
 from oslo_serialization import jsonutils
 import routes
 import six
@@ -217,11 +219,11 @@ class RequestTest(test_utils.BaseTestCase):
                 res = req.get_response(api)
                 self.assertEqual(405, res.status_int)
 
-        """Makes sure not implemented methods return 501"""
+        # Makes sure not implemented methods return 405
         req = webob.Request.blank('/schemas/image')
         req.method = 'NonexistentMethod'
         res = req.get_response(api)
-        self.assertEqual(501, res.status_int)
+        self.assertEqual(405, res.status_int)
 
 
 class ResourceTest(test_utils.BaseTestCase):
@@ -372,18 +374,44 @@ class ResourceTest(test_utils.BaseTestCase):
         e = wsgi.translate_exception(req, e)
         self.assertEqual('No Encontrado', e.explanation)
 
+    def test_response_headers_encoded(self):
+        # prepare environment
+        for_openstack_comrades =  \
+            u'\u0417\u0430 \u043e\u043f\u0435\u043d\u0441\u0442\u0435\u043a, ' \
+            u'\u0442\u043e\u0432\u0430\u0440\u0438\u0449\u0438'
+
+        class FakeController(object):
+            def index(self, shirt, pants=None):
+                return (shirt, pants)
+
+        class FakeSerializer(object):
+            def index(self, response, result):
+                response.headers['unicode_test'] = for_openstack_comrades
+
+        # make request
+        resource = wsgi.Resource(FakeController(), None, FakeSerializer())
+        actions = {'action': 'index'}
+        env = {'wsgiorg.routing_args': [None, actions]}
+        request = wsgi.Request.blank('/tests/123', environ=env)
+        response = resource.__call__(request)
+
+        # ensure it has been encoded correctly
+        value = (response.headers['unicode_test'].decode('utf-8')
+                 if six.PY2 else response.headers['unicode_test'])
+        self.assertEqual(for_openstack_comrades, value)
+
 
 class JSONResponseSerializerTest(test_utils.BaseTestCase):
 
     def test_to_json(self):
         fixture = {"key": "value"}
-        expected = '{"key": "value"}'
+        expected = b'{"key": "value"}'
         actual = wsgi.JSONResponseSerializer().to_json(fixture)
         self.assertEqual(expected, actual)
 
     def test_to_json_with_date_format_value(self):
         fixture = {"date": datetime.datetime(1901, 3, 8, 2)}
-        expected = '{"date": "1901-03-08T02:00:00.000000"}'
+        expected = b'{"date": "1901-03-08T02:00:00.000000"}'
         actual = wsgi.JSONResponseSerializer().to_json(fixture)
         self.assertEqual(expected, actual)
 
@@ -397,7 +425,7 @@ class JSONResponseSerializerTest(test_utils.BaseTestCase):
 
     def test_to_json_with_set(self):
         fixture = set(["foo"])
-        expected = '["foo"]'
+        expected = b'["foo"]'
         actual = wsgi.JSONResponseSerializer().to_json(fixture)
         self.assertEqual(expected, actual)
 
@@ -406,11 +434,11 @@ class JSONResponseSerializerTest(test_utils.BaseTestCase):
         response = webob.Response()
         wsgi.JSONResponseSerializer().default(response, fixture)
         self.assertEqual(200, response.status_int)
-        content_types = filter(lambda h: h[0] == 'Content-Type',
-                               response.headerlist)
+        content_types = [h for h in response.headerlist
+                         if h[0] == 'Content-Type']
         self.assertEqual(1, len(content_types))
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual('{"key": "value"}', response.body)
+        self.assertEqual(b'{"key": "value"}', response.body)
 
 
 class JSONRequestDeserializerTest(test_utils.BaseTestCase):
@@ -418,21 +446,21 @@ class JSONRequestDeserializerTest(test_utils.BaseTestCase):
     def test_has_body_no_content_length(self):
         request = wsgi.Request.blank('/')
         request.method = 'POST'
-        request.body = 'asdf'
+        request.body = b'asdf'
         request.headers.pop('Content-Length')
         self.assertFalse(wsgi.JSONRequestDeserializer().has_body(request))
 
     def test_has_body_zero_content_length(self):
         request = wsgi.Request.blank('/')
         request.method = 'POST'
-        request.body = 'asdf'
+        request.body = b'asdf'
         request.headers['Content-Length'] = 0
         self.assertFalse(wsgi.JSONRequestDeserializer().has_body(request))
 
     def test_has_body_has_content_length(self):
         request = wsgi.Request.blank('/')
         request.method = 'POST'
-        request.body = 'asdf'
+        request.body = b'asdf'
         self.assertIn('Content-Length', request.headers)
         self.assertTrue(wsgi.JSONRequestDeserializer().has_body(request))
 
@@ -460,7 +488,7 @@ class JSONRequestDeserializerTest(test_utils.BaseTestCase):
     def test_default_with_body(self):
         request = wsgi.Request.blank('/')
         request.method = 'POST'
-        request.body = '{"key": "value"}'
+        request.body = b'{"key": "value"}'
         actual = wsgi.JSONRequestDeserializer().default(request)
         expected = {"body": {"key": "value"}}
         self.assertEqual(expected, actual)
@@ -489,7 +517,7 @@ class JSONRequestDeserializerTest(test_utils.BaseTestCase):
                                  content_length=None):
         request = wsgi.Request.blank('/')
         request.method = 'POST'
-        request.body = 'fake_body'
+        request.body = b'fake_body'
         request.headers['transfer-encoding'] = transfer_encoding
         if content_length is not None:
             request.headers['content-length'] = content_length
@@ -530,6 +558,23 @@ class ServerTest(test_utils.BaseTestCase):
                                                 keepalive=False,
                                                 socket_timeout=900)
 
+    def test_number_of_workers(self):
+        """Ensure the default number of workers matches num cpus."""
+        def pid():
+            i = 1
+            while True:
+                i = i + 1
+                yield i
+
+        with mock.patch.object(os, 'fork') as mock_fork:
+            mock_fork.side_effect = pid
+            server = wsgi.Server()
+            server.configure = mock.Mock()
+            fake_application = "fake-application"
+            server.start(fake_application, None)
+            self.assertEqual(processutils.get_worker_count(),
+                             len(server.children))
+
 
 class TestHelpers(test_utils.BaseTestCase):
 
