@@ -15,13 +15,13 @@
 #    under the License.
 
 from oslo_serialization import jsonutils
-from oslo_utils import timeutils
 from oslotest import moxstubout
 import webob
 
 from glance.api import authorization
 from glance.common import auth
 from glance.common import exception
+from glance.common import timeutils
 import glance.domain
 from glance.tests.unit import utils as unittest_utils
 from glance.tests import utils
@@ -768,6 +768,12 @@ class TestImmutableImage(utils.BaseTestCase):
         self.assertRaises(exception.Forbidden,
                           self.image.set_data, 'blah', 4)
 
+    def test_deactivate_image(self):
+        self.assertRaises(exception.Forbidden, self.image.deactivate)
+
+    def test_reactivate_image(self):
+        self.assertRaises(exception.Forbidden, self.image.reactivate)
+
     def test_get_data(self):
         class FakeImage(object):
             def get_data(self):
