@@ -20,14 +20,14 @@ import uuid
 import mock
 from oslo_config import cfg
 import oslo_utils.importutils
-from oslo_utils import timeutils
 
-from glance.artifacts import domain as artifacts_domain
 import glance.async
 from glance.async import taskflow_executor
-from glance.common.artifacts import definitions
 from glance.common import exception
+from glance.common.glare import definitions
+from glance.common import timeutils
 from glance import domain
+from glance.glare import domain as artifacts_domain
 import glance.tests.utils as test_utils
 
 
@@ -326,7 +326,9 @@ class TestTaskFactory(test_utils.BaseTestCase):
         owner = TENANT1
         task_input = 'input'
         task = self.task_factory.new_task(task_type, owner,
-                                          task_input=task_input)
+                                          task_input=task_input,
+                                          result='test_result',
+                                          message='test_message')
         self.assertIsNotNone(task.task_id)
         self.assertIsNotNone(task.created_at)
         self.assertEqual(task_type, task.type)
@@ -335,8 +337,8 @@ class TestTaskFactory(test_utils.BaseTestCase):
         self.assertIsNone(task.expires_at)
         self.assertEqual(owner, task.owner)
         self.assertEqual(task_input, task.task_input)
-        self.assertEqual(u'', task.message)
-        self.assertIsNone(task.result)
+        self.assertEqual('test_message', task.message)
+        self.assertEqual('test_result', task.result)
 
     def test_new_task_invalid_type(self):
         task_type = 'blah'
