@@ -18,6 +18,7 @@ import sys
 import uuid
 
 import fixtures
+import mock
 from oslo_serialization import jsonutils
 import six
 from six import moves
@@ -77,8 +78,7 @@ class FakeHTTPConnection(object):
         if not url.startswith('/'):
             url = '/' + url
         url = unit_test_utils.sort_url_by_qs_keys(url)
-        hkeys = in_headers.keys()
-        hkeys.sort()
+        hkeys = sorted(in_headers.keys())
         hashable = (method, url, in_body, ' '.join(hkeys))
 
         flat_headers = []
@@ -90,8 +90,7 @@ class FakeHTTPConnection(object):
     def request(self, method, url, body, headers):
         self.count += 1
         url = unit_test_utils.sort_url_by_qs_keys(url)
-        hkeys = headers.keys()
-        hkeys.sort()
+        hkeys = sorted(headers.keys())
         hashable = (method, url, body, ' '.join(hkeys))
 
         if hashable not in self.reqs:
@@ -245,7 +244,7 @@ class ImageServiceTestCase(test_utils.BaseTestCase):
 class FakeHttpResponse(object):
     def __init__(self, headers, data):
         self.headers = headers
-        self.data = six.StringIO(data)
+        self.data = six.BytesIO(data)
 
     def getheaders(self):
         return self.headers
@@ -284,7 +283,7 @@ class FakeImageService(object):
         return FAKEIMAGES
 
     def get_image(self, id):
-        return FakeHttpResponse({}, 'data')
+        return FakeHttpResponse({}, b'data')
 
     def get_image_meta(self, id):
         for img in FAKEIMAGES:
@@ -336,6 +335,17 @@ def check_bad_args(command, args):
 
 
 class ReplicationCommandsTestCase(test_utils.BaseTestCase):
+
+    @mock.patch.object(glance_replicator, 'lookup_command')
+    def test_help(self, mock_lookup_command):
+        option = mock.Mock()
+        mock_lookup_command.return_value = "fake_return"
+
+        glance_replicator.print_help(option, [])
+        glance_replicator.print_help(option, ['dump'])
+        glance_replicator.print_help(option, ['fake_command'])
+        self.assertEqual(2, mock_lookup_command.call_count)
+
     def test_replication_size(self):
         options = moves.UserDict()
         options.slavetoken = 'slavetoken'
