@@ -15,12 +15,9 @@
 #    under the License.
 
 """
-Tests for database migrations. This test case reads the configuration
-file /tests/unit/test_migrations.conf for database connection settings
-to use in the tests. For each connection found in the config file,
-the test case runs a series of test cases to ensure that migrations work
-properly both upgrading and downgrading, and that no data loss occurs
-if possible.
+Tests for database migrations run a series of test cases to ensure that
+migrations work properly both upgrading and downgrading, and that no data loss
+occurs if possible.
 """
 
 from __future__ import print_function
@@ -37,7 +34,7 @@ from oslo_db.sqlalchemy import test_base
 from oslo_db.sqlalchemy import test_migrations
 from oslo_db.sqlalchemy import utils as db_utils
 from oslo_serialization import jsonutils
-from oslo_utils import timeutils
+from oslo_utils import uuidutils
 # NOTE(jokke): simplified transition to py3, behaves like py2 xrange
 from six.moves import range
 import sqlalchemy
@@ -46,17 +43,15 @@ import sqlalchemy.types as types
 
 from glance.common import crypt
 from glance.common import exception
-from glance.common import utils
+from glance.common import timeutils
 from glance.db import migration
 from glance.db.sqlalchemy import migrate_repo
 from glance.db.sqlalchemy.migrate_repo.schema import from_migration_import
 from glance.db.sqlalchemy import models
-from glance.db.sqlalchemy import models_artifacts
+from glance.db.sqlalchemy import models_glare
 from glance.db.sqlalchemy import models_metadef
 
-from glance import i18n
-
-_ = i18n._
+from glance.i18n import _
 
 CONF = cfg.CONF
 CONF.import_opt('metadata_encryption_key', 'glance.common.config')
@@ -347,7 +342,7 @@ class MigrationsMixin(test_migrations.WalkVersionsMixin):
             self.assertEqual(1, len(rows))
 
             row = rows[0]
-            self.assertTrue(utils.is_uuid_like(row['id']))
+            self.assertTrue(uuidutils.is_uuid_like(row['id']))
 
             uuids[name] = row['id']
 
@@ -386,7 +381,7 @@ class MigrationsMixin(test_migrations.WalkVersionsMixin):
             self.assertEqual(1, len(rows))
 
             row = rows[0]
-            self.assertFalse(utils.is_uuid_like(row['id']))
+            self.assertFalse(uuidutils.is_uuid_like(row['id']))
 
             ids[name] = row['id']
 
@@ -421,7 +416,7 @@ class MigrationsMixin(test_migrations.WalkVersionsMixin):
 
         invalid_scheme_uri = ('http://acct:usr:pass@example.com'
                               '/container/obj-id')
-        self.assertRaises(AssertionError,
+        self.assertRaises(exception.BadStoreUri,
                           legacy_parse_uri_fn,
                           invalid_scheme_uri,
                           True)
@@ -503,7 +498,7 @@ class MigrationsMixin(test_migrations.WalkVersionsMixin):
             'file://foo',
         ]
         result = images.select().execute()
-        locations = map(lambda x: x['location'], result)
+        locations = list(map(lambda x: x['location'], result))
         for loc in quoted_locations:
             self.assertIn(loc, locations)
 
@@ -539,7 +534,8 @@ class MigrationsMixin(test_migrations.WalkVersionsMixin):
 
     def test_legacy_parse_swift_uri_017(self):
         metadata_encryption_key = 'a' * 16
-        CONF.set_override('metadata_encryption_key', metadata_encryption_key)
+        CONF.set_override('metadata_encryption_key', metadata_encryption_key,
+                          enforce_type=True)
         self.addCleanup(CONF.reset)
         (legacy_parse_uri, encrypt_location) = from_migration_import(
             '017_quote_encrypted_swift_credentials', ['legacy_parse_uri',
@@ -554,7 +550,8 @@ class MigrationsMixin(test_migrations.WalkVersionsMixin):
 
     def _pre_upgrade_017(self, engine):
         metadata_encryption_key = 'a' * 16
-        CONF.set_override('metadata_encryption_key', metadata_encryption_key)
+        CONF.set_override('metadata_encryption_key', metadata_encryption_key,
+                          enforce_type=True)
         self.addCleanup(CONF.reset)
         images = db_utils.get_table(engine, 'images')
         unquoted = 'swift://acct:usr:pass@example.com/container/obj-id'
@@ -599,7 +596,7 @@ class MigrationsMixin(test_migrations.WalkVersionsMixin):
         quoted = 'swift://acct%3Ausr:pass@example.com/container/obj-id'
         images = db_utils.get_table(engine, 'images')
         result = images.select().execute()
-        locations = map(lambda x: x['location'], result)
+        locations = list(map(lambda x: x['location'], result))
         actual_location = []
         for location in locations:
             if location:
@@ -639,8 +636,8 @@ class MigrationsMixin(test_migrations.WalkVersionsMixin):
             # not be migrated
             {'id': 'fake-19-2', 'location': None},
         ]
-        map(lambda image: image.update(base_values), data)
         for image in data:
+            image.update(base_values)
             images.insert().values(image).execute()
         return data
 
@@ -907,8 +904,8 @@ class MigrationsMixin(test_migrations.WalkVersionsMixin):
                 'result': None
             },
         ]
-        map(lambda task: task.update(base_values), data)
         for task in data:
+            task.update(base_values)
             tasks.insert().values(task).execute()
         return data
 
@@ -997,7 +994,7 @@ class MigrationsMixin(test_migrations.WalkVersionsMixin):
             r = list(results)
             self.assertEqual(1, len(r))
             self.assertIn('status', r[0])
-            self.assertEqual(r[0]['status'], status_list[idx])
+            self.assertEqual(status_list[idx], r[0]['status'])
 
     def _post_downgrade_033(self, engine):
         image_locations = db_utils.get_table(engine, 'image_locations')
@@ -1829,12 +1826,8 @@ class MigrationsMixin(test_migrations.WalkVersionsMixin):
         index_data = [(index.name, index.columns.keys()) for index in
                       table.indexes]
         column_data = [column.name for column in table.columns]
-        # instead of calling assertItemsEqual, which is not present in py26
-        # asserting equality of lengths and sorted collections
-        self.assertEqual(len(columns), len(column_data))
-        self.assertEqual(sorted(columns), sorted(column_data))
-        self.assertEqual(len(indices), len(index_data))
-        self.assertEqual(sorted(indices), sorted(index_data))
+        self.assertItemsEqual(columns, column_data)
+        self.assertItemsEqual(indices, index_data)
 
 
 class TestMysqlMigrations(test_base.MySQLOpportunisticTestCase,
@@ -1858,7 +1851,7 @@ class TestMysqlMigrations(test_base.MySQLOpportunisticTestCase,
             "AND TABLE_NAME!='migrate_version'"
             % self.migrate_engine.url.database)
         count = noninnodb.scalar()
-        self.assertEqual(count, 0, "%d non InnoDB tables created" % count)
+        self.assertEqual(0, count, "%d non InnoDB tables created" % count)
 
 
 class TestPostgresqlMigrations(test_base.PostgreSQLOpportunisticTestCase,
@@ -1878,7 +1871,7 @@ class ModelsMigrationSyncMixin(object):
     def get_metadata(self):
         for table in models_metadef.BASE_DICT.metadata.sorted_tables:
             models.BASE.metadata._add_table(table.name, table.schema, table)
-        for table in models_artifacts.BASE.metadata.sorted_tables:
+        for table in models_glare.BASE.metadata.sorted_tables:
             models.BASE.metadata._add_table(table.name, table.schema, table)
         return models.BASE.metadata
 
