@@ -13,12 +13,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import urllib
 
+from cryptography import exceptions as crypto_exception
+from debtcollector import removals
 import glance_store as store
+import mock
 from oslo_config import cfg
 from oslo_log import log as logging
-import six.moves.urllib.parse as urlparse
+from six.moves import urllib
 
 from glance.common import exception
 from glance.common import store_utils
@@ -50,21 +52,24 @@ def sort_url_by_qs_keys(url):
     # non-deterministic ordering of the query string causing problems with unit
     # tests.
 
-    parsed = urlparse.urlparse(url)
-    queries = urlparse.parse_qsl(parsed.query, True)
+    parsed = urllib.parse.urlparse(url)
+    queries = urllib.parse.parse_qsl(parsed.query, True)
     sorted_query = sorted(queries, key=lambda x: x[0])
 
-    encoded_sorted_query = urllib.urlencode(sorted_query, True)
+    encoded_sorted_query = urllib.parse.urlencode(sorted_query, True)
 
     url_parts = (parsed.scheme, parsed.netloc, parsed.path,
                  parsed.params, encoded_sorted_query,
                  parsed.fragment)
 
-    return urlparse.urlunparse(url_parts)
+    return urllib.parse.urlunparse(url_parts)
 
 
 def get_fake_request(path='', method='POST', is_admin=False, user=USER1,
-                     roles=['member'], tenant=TENANT1):
+                     roles=None, tenant=TENANT1):
+    if roles is None:
+            roles = ['member']
+
     req = wsgi.Request.blank(path)
     req.method = method
 
@@ -83,7 +88,8 @@ def fake_get_size_from_backend(uri, context=None):
     return 1
 
 
-def fake_verify_signature(context, checksum_hash, image_properties):
+@removals.remove(message="This will be removed in the N cycle.")
+def fake_old_verify_signature(context, checksum_hash, image_properties):
     if (image_properties is not None and 'signature' in image_properties and
             image_properties['signature'] == 'VALID'):
         return True
@@ -92,6 +98,17 @@ def fake_verify_signature(context, checksum_hash, image_properties):
             'Signature verification failed.')
 
 
+def fake_get_verifier(context, image_properties):
+    verifier = mock.Mock()
+    if (image_properties is not None and 'img_signature' in image_properties
+            and image_properties['img_signature'] == 'VALID'):
+        verifier.verify.return_value = None
+    else:
+        ex = crypto_exception.InvalidSignature()
+        verifier.verify.side_effect = ex
+    return verifier
+
+
 class FakeDB(object):
 
     def __init__(self, initialize=True):
@@ -147,7 +164,7 @@ class FakeStoreUtils(object):
             self.safe_delete_from_backend(context, image_id, location)
 
     def validate_external_location(self, uri):
-        if uri and urlparse.urlparse(uri).scheme:
+        if uri and urllib.parse.urlparse(uri).scheme:
             return store_utils.validate_external_location(uri)
         else:
             return True
@@ -195,7 +212,7 @@ class FakeStoreAPI(object):
         return self.get_from_backend(location, context=context)[1]
 
     def add_to_backend(self, conf, image_id, data, size,
-                       scheme=None, context=None):
+                       scheme=None, context=None, verifier=None):
         store_max_size = 7
         current_store_size = 2
         for location in self.data.keys():
