@@ -21,7 +21,6 @@ import uuid
 import mock
 from oslo_config import cfg
 from oslo_serialization import jsonutils
-from oslo_utils import timeutils
 import routes
 import six
 import webob
@@ -29,6 +28,7 @@ import webob
 import glance.api.common
 import glance.common.config
 from glance.common import crypt
+from glance.common import timeutils
 from glance import context
 from glance.db.sqlalchemy import api as db_api
 from glance.db.sqlalchemy import models as db_models
@@ -45,7 +45,6 @@ UUID2 = _gen_uuid()
 
 
 class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
-
     def setUp(self):
         """Establish a clean test environment"""
         super(TestRegistryAPI, self).setUp()
@@ -209,7 +208,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         when a malformed marker is provided
         """
         res = self.get_api_response_ext(400, url='/images?marker=4')
-        self.assertIn('marker', res.body)
+        self.assertIn(b'marker', res.body)
 
     def test_get_index_forbidden_marker(self):
         """
@@ -712,7 +711,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         when a malformed marker is provided
         """
         res = self.get_api_response_ext(400, url='/images/detail?marker=4')
-        self.assertIn('marker', res.body)
+        self.assertIn(b'marker', res.body)
 
     def test_get_details_forbidden_marker(self):
         """
@@ -889,7 +888,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         self.assertEqual(2, len(images))
 
         for image in images:
-            self.assertTrue(image['size'] >= 19)
+            self.assertGreaterEqual(image['size'], 19)
 
     def test_get_details_filter_size_max(self):
         """
@@ -912,7 +911,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         self.assertEqual(2, len(images))
 
         for image in images:
-            self.assertTrue(image['size'] <= 19)
+            self.assertLessEqual(image['size'], 19)
 
     def test_get_details_filter_size_min_max(self):
         """
@@ -1207,7 +1206,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         """Tests that the /images POST registry API creates the image"""
 
         fixture = self.get_minimal_fixture()
-        body = jsonutils.dumps(dict(image=fixture))
+        body = jsonutils.dump_as_bytes(dict(image=fixture))
 
         res = self.get_api_response_ext(200, body=body,
                                         method='POST', content_type='json')
@@ -1222,7 +1221,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
     def test_create_image_with_min_disk(self):
         """Tests that the /images POST registry API creates the image"""
         fixture = self.get_minimal_fixture(min_disk=5)
-        body = jsonutils.dumps(dict(image=fixture))
+        body = jsonutils.dump_as_bytes(dict(image=fixture))
 
         res = self.get_api_response_ext(200, body=body,
                                         method='POST', content_type='json')
@@ -1233,7 +1232,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
     def test_create_image_with_min_ram(self):
         """Tests that the /images POST registry API creates the image"""
         fixture = self.get_minimal_fixture(min_ram=256)
-        body = jsonutils.dumps(dict(image=fixture))
+        body = jsonutils.dump_as_bytes(dict(image=fixture))
 
         res = self.get_api_response_ext(200, body=body,
                                         method='POST', content_type='json')
@@ -1244,7 +1243,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
     def test_create_image_with_min_ram_default(self):
         """Tests that the /images POST registry API creates the image"""
         fixture = self.get_minimal_fixture()
-        body = jsonutils.dumps(dict(image=fixture))
+        body = jsonutils.dump_as_bytes(dict(image=fixture))
 
         res = self.get_api_response_ext(200, body=body,
                                         method='POST', content_type='json')
@@ -1255,7 +1254,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
     def test_create_image_with_min_disk_default(self):
         """Tests that the /images POST registry API creates the image"""
         fixture = self.get_minimal_fixture()
-        body = jsonutils.dumps(dict(image=fixture))
+        body = jsonutils.dump_as_bytes(dict(image=fixture))
 
         res = self.get_api_response_ext(200, body=body,
                                         method='POST', content_type='json')
@@ -1266,18 +1265,19 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
     def test_create_image_with_bad_status(self):
         """Tests proper exception is raised if a bad status is set"""
         fixture = self.get_minimal_fixture(id=_gen_uuid(), status='bad status')
-        body = jsonutils.dumps(dict(image=fixture))
+        body = jsonutils.dump_as_bytes(dict(image=fixture))
 
         res = self.get_api_response_ext(400, body=body,
                                         method='POST', content_type='json')
-        self.assertIn('Invalid image status', res.body)
+        self.assertIn(b'Invalid image status', res.body)
 
     def test_create_image_with_bad_id(self):
         """Tests proper exception is raised if a bad disk_format is set"""
         fixture = self.get_minimal_fixture(id='asdf')
 
+        body = jsonutils.dump_as_bytes(dict(image=fixture))
         self.get_api_response_ext(400, content_type='json', method='POST',
-                                  body=jsonutils.dumps(dict(image=fixture)))
+                                  body=body)
 
     def test_create_image_with_image_id_in_log(self):
         """Tests correct image id in log message when creating image"""
@@ -1285,14 +1285,16 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
             id='0564c64c-3545-4e34-abfb-9d18e5f2f2f9')
         self.log_image_id = False
 
-        def fake_log_info(msg):
-            if ('Successfully created image '
-               '0564c64c-3545-4e34-abfb-9d18e5f2f2f9' in msg):
+        def fake_log_info(msg, image_data):
+            if ('0564c64c-3545-4e34-abfb-9d18e5f2f2f9' == image_data['id'] and
+                    'Successfully created image' in msg):
                 self.log_image_id = True
+
         self.stubs.Set(rserver.images.LOG, 'info', fake_log_info)
 
+        body = jsonutils.dump_as_bytes(dict(image=fixture))
         self.get_api_response_ext(200, content_type='json', method='POST',
-                                  body=jsonutils.dumps(dict(image=fixture)))
+                                  body=body)
         self.assertTrue(self.log_image_id)
 
     def test_update_image(self):
@@ -1301,7 +1303,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
                    'min_disk': 5,
                    'min_ram': 256,
                    'disk_format': 'raw'}
-        body = jsonutils.dumps(dict(image=fixture))
+        body = jsonutils.dump_as_bytes(dict(image=fixture))
 
         res = self.get_api_response_ext(200, url='/images/%s' % UUID2,
                                         body=body, method='PUT',
@@ -1330,7 +1332,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
                    'min_ram': 256,
                    'disk_format': 'raw',
                    'location': 'fake://image'}
-        body = jsonutils.dumps(dict(image=fixture))
+        body = jsonutils.dump_as_bytes(dict(image=fixture))
 
         log_debug.side_effect = fake_log_debug
 
@@ -1352,7 +1354,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         non-existing image
         """
         fixture = {'status': 'killed'}
-        body = jsonutils.dumps(dict(image=fixture))
+        body = jsonutils.dump_as_bytes(dict(image=fixture))
 
         self.get_api_response_ext(404, url='/images/%s' % _gen_uuid(),
                                   method='PUT', body=body, content_type='json')
@@ -1360,12 +1362,12 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
     def test_update_image_with_bad_status(self):
         """Tests that exception raised trying to set a bad status"""
         fixture = {'status': 'invalid'}
-        body = jsonutils.dumps(dict(image=fixture))
+        body = jsonutils.dump_as_bytes(dict(image=fixture))
 
         res = self.get_api_response_ext(400, method='PUT', body=body,
                                         url='/images/%s' % UUID2,
                                         content_type='json')
-        self.assertIn('Invalid image status', res.body)
+        self.assertIn(b'Invalid image status', res.body)
 
     def test_update_private_image_no_admin(self):
         """
@@ -1379,7 +1381,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         db_api.image_create(self.context, extra_fixture)
         test_rserv = rserver.API(self.mapper)
         api = test_utils.FakeAuthMiddleware(test_rserv, is_admin=False)
-        body = jsonutils.dumps(dict(image=extra_fixture))
+        body = jsonutils.dump_as_bytes(dict(image=extra_fixture))
         self.get_api_response_ext(404, body=body, api=api,
                                   url='/images/%s' % UUID8, method='PUT',
                                   content_type='json')
@@ -1402,7 +1404,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         res_dict = jsonutils.loads(res.body)
 
         new_num_images = len(res_dict['images'])
-        self.assertEqual(new_num_images, orig_num_images - 1)
+        self.assertEqual(orig_num_images - 1, new_num_images)
 
     def test_delete_image_response(self):
         """Tests that the registry API delete returns the image metadata"""
@@ -1463,7 +1465,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
 
         memb_list = jsonutils.loads(res.body)
         num_members = len(memb_list['members'])
-        self.assertEqual(num_members, 0)
+        self.assertEqual(0, num_members)
 
     def test_get_image_members_not_existing(self):
         """
@@ -1498,7 +1500,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
 
         memb_list = jsonutils.loads(res.body)
         num_members = len(memb_list['shared_images'])
-        self.assertEqual(num_members, 0)
+        self.assertEqual(0, num_members)
 
     def test_replace_members(self):
         """
@@ -1507,7 +1509,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         self.api = test_utils.FakeAuthMiddleware(rserver.API(self.mapper),
                                                  is_admin=False)
         fixture = dict(member_id='pattieblack')
-        body = jsonutils.dumps(dict(image_memberships=fixture))
+        body = jsonutils.dump_as_bytes(dict(image_memberships=fixture))
 
         self.get_api_response_ext(401, method='PUT', body=body,
                                   url='/images/%s/members' % UUID2,
@@ -1523,9 +1525,9 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         req.method = 'PUT'
         self.context.tenant = 'test2'
         req.content_type = 'application/json'
-        req.body = jsonutils.dumps(dict(image_memberships=fixture))
+        req.body = jsonutils.dump_as_bytes(dict(image_memberships=fixture))
         res = req.get_response(self.api)
-        self.assertEqual(res.status_int, 404)
+        self.assertEqual(404, res.status_int)
 
     def test_update_all_image_members_invalid_membership_association(self):
         """
@@ -1547,10 +1549,10 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
 
         memb_list = jsonutils.loads(res.body)
         num_members = len(memb_list['members'])
-        self.assertEqual(num_members, 1)
+        self.assertEqual(1, num_members)
 
         fixture = dict(member_id='test1')
-        body = jsonutils.dumps(dict(image_memberships=fixture))
+        body = jsonutils.dump_as_bytes(dict(image_memberships=fixture))
         self.get_api_response_ext(400, url='/images/%s/members' % UUID8,
                                   method='PUT', body=body,
                                   content_type='json')
@@ -1570,10 +1572,10 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         req.headers['X-Auth-Token'] = 'test1:test1:'
         req.method = 'PUT'
         req.content_type = 'application/json'
-        req.body = jsonutils.dumps(dict(image_memberships=fixture))
+        req.body = jsonutils.dump_as_bytes(dict(image_memberships=fixture))
 
         res = req.get_response(api)
-        self.assertEqual(res.status_int, 403)
+        self.assertEqual(403, res.status_int)
 
     def test_update_all_image_members(self):
         """
@@ -1591,7 +1593,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         req.get_response(self.api)
 
         fixture = [dict(member_id='test2', can_share=True)]
-        body = jsonutils.dumps(dict(memberships=fixture))
+        body = jsonutils.dump_as_bytes(dict(memberships=fixture))
         self.get_api_response_ext(204, url='/images/%s/members' % UUID8,
                                   method='PUT', body=body,
                                   content_type='json')
@@ -1612,7 +1614,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         req.method = 'PUT'
         req.get_response(self.api)
         fixture = dict(member_id='test3')
-        body = jsonutils.dumps(dict(memberships=fixture))
+        body = jsonutils.dump_as_bytes(dict(memberships=fixture))
         self.get_api_response_ext(400, url='/images/%s/members' % UUID8,
                                   method='PUT', body=body,
                                   content_type='json')
@@ -1633,11 +1635,39 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         req.get_response(self.api)
 
         fixture = [dict(member_id='test1', can_share=False)]
-        body = jsonutils.dumps(dict(memberships=fixture))
+        body = jsonutils.dump_as_bytes(dict(memberships=fixture))
         self.get_api_response_ext(204, url='/images/%s/members' % UUID8,
                                   method='PUT', body=body,
                                   content_type='json')
 
+    def test_update_all_image_existing_deleted_members(self):
+        """
+        Test update existing image members
+        """
+        UUID8 = _gen_uuid()
+        extra_fixture = self.get_fixture(id=UUID8, size=19, protected=False,
+                                         owner='test user')
+
+        db_api.image_create(self.context, extra_fixture)
+
+        # Add a new member to an image
+        req = webob.Request.blank('/images/%s/members/test1' % UUID8)
+        req.method = 'PUT'
+        req.get_response(self.api)
+
+        # Delete the existing member
+        self.get_api_response_ext(204, method='DELETE',
+                                  url='/images/%s/members/test1' % UUID8)
+
+        # Re-add the deleted member by replacing membership list
+        fixture = [dict(member_id='test1', can_share=False)]
+        body = jsonutils.dump_as_bytes(dict(memberships=fixture))
+        self.get_api_response_ext(204, url='/images/%s/members' % UUID8,
+                                  method='PUT', body=body,
+                                  content_type='json')
+        memb_list = db_api.image_member_find(self.context, image_id=UUID8)
+        self.assertEqual(1, len(memb_list))
+
     def test_add_member(self):
         """
         Tests adding image members raises right exception
@@ -1659,7 +1689,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         db_api.image_create(self.context, extra_fixture)
         fixture = dict(can_share=True)
         test_uri = '/images/%s/members/test_add_member_positive'
-        body = jsonutils.dumps(dict(member=fixture))
+        body = jsonutils.dump_as_bytes(dict(member=fixture))
         self.get_api_response_ext(204, url=test_uri % UUID8,
                                   method='PUT', body=body,
                                   content_type='json')
@@ -1671,7 +1701,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         """
         fixture = dict(can_share=True)
         test_uri = '/images/%s/members/test_add_member_positive'
-        body = jsonutils.dumps(dict(member=fixture))
+        body = jsonutils.dump_as_bytes(dict(member=fixture))
         self.get_api_response_ext(404, url=test_uri % _gen_uuid(),
                                   method='PUT', body=body,
                                   content_type='json')
@@ -1692,10 +1722,10 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         req.headers['X-Auth-Token'] = 'test1:test1:'
         req.method = 'PUT'
         req.content_type = 'application/json'
-        req.body = jsonutils.dumps(dict(member=fixture))
+        req.body = jsonutils.dump_as_bytes(dict(member=fixture))
 
         res = req.get_response(api)
-        self.assertEqual(res.status_int, 403)
+        self.assertEqual(403, res.status_int)
 
     def test_add_member_to_image_bad_request(self):
         """
@@ -1709,7 +1739,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
 
         fixture = [dict(can_share=True)]
         test_uri = '/images/%s/members/test_add_member_bad_request'
-        body = jsonutils.dumps(dict(member=fixture))
+        body = jsonutils.dump_as_bytes(dict(member=fixture))
         self.get_api_response_ext(400, url=test_uri % UUID8,
                                   method='PUT', body=body,
                                   content_type='json')
@@ -1733,7 +1763,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         res = self.get_api_response_ext(404, method='DELETE',
                                         url=('/images/%s/members/pattieblack' %
                                              UUID2))
-        self.assertIn('Membership could not be found', res.body)
+        self.assertIn(b'Membership could not be found', res.body)
 
     def test_delete_member_from_non_exist_image(self):
         """
@@ -1764,7 +1794,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         req.content_type = 'application/json'
 
         res = req.get_response(api)
-        self.assertEqual(res.status_int, 403)
+        self.assertEqual(403, res.status_int)
 
     def test_add_member_delete_create(self):
         """
@@ -1779,7 +1809,7 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         db_api.image_create(self.context, extra_fixture)
         fixture = dict(can_share=True)
         test_uri = '/images/%s/members/test_add_member_delete_create'
-        body = jsonutils.dumps(dict(member=fixture))
+        body = jsonutils.dump_as_bytes(dict(member=fixture))
         self.get_api_response_ext(204, url=test_uri % UUID8,
                                   method='PUT', body=body,
                                   content_type='json')
@@ -1837,7 +1867,6 @@ class TestRegistryAPI(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
 
 class TestRegistryAPILocations(base.IsolatedUnitTest,
                                test_utils.RegistryAPIMixIn):
-
     def setUp(self):
         """Establish a clean test environment"""
         super(TestRegistryAPILocations, self).setUp()
@@ -1928,7 +1957,7 @@ class TestRegistryAPILocations(base.IsolatedUnitTest,
         req = webob.Request.blank('/images')
         req.method = 'POST'
         req.content_type = 'application/json'
-        req.body = jsonutils.dumps(dict(image=fixture))
+        req.body = jsonutils.dump_as_bytes(dict(image=fixture))
 
         res = req.get_response(self.api)
         self.assertEqual(200, res.status_int)
@@ -1948,10 +1977,10 @@ class TestRegistryAPILocations(base.IsolatedUnitTest,
                          image['location_data'][1]['metadata'])
 
         image_entry = db_api.image_get(self.context, image['id'])
-        self.assertEqual(image_entry['locations'][0]['url'],
-                         encrypted_location_url1)
-        self.assertEqual(image_entry['locations'][1]['url'],
-                         encrypted_location_url2)
+        self.assertEqual(encrypted_location_url1,
+                         image_entry['locations'][0]['url'])
+        self.assertEqual(encrypted_location_url2,
+                         image_entry['locations'][1]['url'])
         decrypted_location_url1 = crypt.urlsafe_decrypt(
             encryption_key, image_entry['locations'][0]['url'])
         decrypted_location_url2 = crypt.urlsafe_decrypt(
@@ -1961,7 +1990,6 @@ class TestRegistryAPILocations(base.IsolatedUnitTest,
 
 
 class TestSharability(test_utils.BaseTestCase):
-
     def setUp(self):
         super(TestSharability, self).setUp()
         self.setup_db()
