@@ -19,13 +19,14 @@ import os
 import uuid
 
 from mock import patch
-from oslo_utils import timeutils
+from six.moves import reload_module
 import testtools
 
 from glance.api.v1.images import Controller as acontroller
 from glance.common import client as test_client
 from glance.common import config
 from glance.common import exception
+from glance.common import timeutils
 from glance import context
 from glance.db.sqlalchemy import api as db_api
 from glance.registry.api.v1.images import Controller as rcontroller
@@ -496,7 +497,7 @@ class TestRegistryV1Client(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
 
         self.assertEqual(1, len(images))
         for image in images:
-            self.assertTrue(image['size'] <= 20)
+            self.assertLessEqual(image['size'], 20)
 
     def test_get_image_details_with_minimum_size(self):
         """Tests that a detailed call can be filtered by size_min"""
@@ -508,7 +509,7 @@ class TestRegistryV1Client(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
 
         self.assertEqual(1, len(images))
         for image in images:
-            self.assertTrue(image['size'] >= 20)
+            self.assertGreaterEqual(image['size'], 20)
 
     def test_get_image_details_with_changes_since(self):
         """Tests that a detailed call can be filtered by changes-since"""
@@ -564,7 +565,7 @@ class TestRegistryV1Client(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         self.assertEqual(1, len(images))
 
         for image in images:
-            self.assertTrue(image['size'] >= 20)
+            self.assertGreaterEqual(image['size'], 20)
 
     def test_get_image_details_by_property(self):
         """Tests that a detailed call can be filtered by a property"""
@@ -843,7 +844,7 @@ class TestRegistryV1ClientApi(base.IsolatedUnitTest):
         """Establish a clean test environment."""
         super(TestRegistryV1ClientApi, self).setUp()
         self.context = context.RequestContext()
-        reload(rapi)
+        reload_module(rapi)
 
     def tearDown(self):
         """Clear the test environment."""
