@@ -228,7 +228,7 @@ class TestImagesController(base.StoreClearingUnitTest):
                               request, str(uuid.uuid4()), 'ABC', 3)
             self.assertTrue(image.delete.called)
 
-    def test_upload_non_existent_image_raises_not_found_exception(self):
+    def test_upload_non_existent_image_raises_image_not_found_exception(self):
         def fake_save(self):
             raise exception.ImageNotFound()
 
@@ -243,6 +243,21 @@ class TestImagesController(base.StoreClearingUnitTest):
         self.assertRaises(webob.exc.HTTPGone, self.controller.upload,
                           request, str(uuid.uuid4()), 'ABC', 3)
 
+    def test_upload_non_existent_image_raises_store_not_found_exception(self):
+        def fake_save(self):
+            raise glance_store.NotFound()
+
+        def fake_delete():
+            raise exception.ImageNotFound()
+
+        request = unit_test_utils.get_fake_request()
+        image = FakeImage('abcd', locations=['http://example.com/image'])
+        self.image_repo.result = image
+        self.image_repo.save = fake_save
+        image.delete = fake_delete
+        self.assertRaises(webob.exc.HTTPGone, self.controller.upload,
+                          request, str(uuid.uuid4()), 'ABC', 3)
+
     def test_upload_non_existent_image_before_save(self):
         request = unit_test_utils.get_fake_request()
         self.image_repo.result = exception.NotFound()
@@ -327,6 +342,59 @@ class TestImagesController(base.StoreClearingUnitTest):
                           self.controller.upload,
                           request, unit_test_utils.UUID2, 'YY', 2)
 
+    @mock.patch("glance.common.trust_auth.TokenRefresher")
+    def test_upload_with_trusts(self, mock_refresher):
+        """Test that uploading with registry correctly uses trusts"""
+        # initialize trust environment
+        self.config(data_api='glance.db.registry.api')
+        refresher = mock.MagicMock()
+        mock_refresher.return_value = refresher
+        refresher.refresh_token.return_value = "fake_token"
+        # request an image upload
+        request = unit_test_utils.get_fake_request()
+        request.environ['keystone.token_auth'] = mock.MagicMock()
+        request.environ['keystone.token_info'] = {
+            'token': {
+                'roles': [{'name': 'FakeRole', 'id': 'FakeID'}]
+            }
+        }
+        image = FakeImage('abcd')
+        self.image_repo.result = image
+        mock_fake_save = mock.Mock()
+        mock_fake_save.side_effect = [None, exception.NotAuthenticated, None]
+        temp_save = FakeImageRepo.save
+        # mocking save to raise NotAuthenticated on the second call
+        FakeImageRepo.save = mock_fake_save
+        self.controller.upload(request, unit_test_utils.UUID2, 'YYYY', 4)
+        # check image data
+        self.assertEqual('YYYY', image.data)
+        self.assertEqual(4, image.size)
+        FakeImageRepo.save = temp_save
+        # check that token has been correctly acquired and deleted
+        mock_refresher.assert_called_once_with(
+            request.environ['keystone.token_auth'],
+            request.context.tenant, ['FakeRole'])
+        refresher.refresh_token.assert_called_once_with()
+        refresher.release_resources.assert_called_once_with()
+        self.assertEqual("fake_token", request.context.auth_token)
+
+    @mock.patch("glance.common.trust_auth.TokenRefresher")
+    def test_upload_with_trusts_fails(self, mock_refresher):
+        """Test upload with registry if trust was not successfully created"""
+        # initialize trust environment
+        self.config(data_api='glance.db.registry.api')
+        mock_refresher().side_effect = Exception()
+        # request an image upload
+        request = unit_test_utils.get_fake_request()
+        image = FakeImage('abcd')
+        self.image_repo.result = image
+        self.controller.upload(request, unit_test_utils.UUID2, 'YYYY', 4)
+        # check image data
+        self.assertEqual('YYYY', image.data)
+        self.assertEqual(4, image.size)
+        # check that the token has not been updated
+        self.assertEqual(0, mock_refresher().refresh_token.call_count)
+
     def _test_upload_download_prepare_notification(self):
         request = unit_test_utils.get_fake_request()
         self.controller.upload(request, unit_test_utils.UUID2, 'YYYY', 4)
@@ -347,8 +415,8 @@ class TestImagesController(base.StoreClearingUnitTest):
         self.assertEqual(3, len(output_log))
         prepare_updated_at = output_log[0]['payload']['updated_at']
         del output_log[0]['payload']['updated_at']
-        self.assertTrue(prepare_updated_at <= output['meta']['updated_at'])
-        self.assertEqual(output_log[0], prepare_log)
+        self.assertLessEqual(prepare_updated_at, output['meta']['updated_at'])
+        self.assertEqual(prepare_log, output_log[0])
 
     def _test_upload_download_upload_notification(self):
         request = unit_test_utils.get_fake_request()
@@ -362,7 +430,7 @@ class TestImagesController(base.StoreClearingUnitTest):
             'payload': upload_payload,
         }
         self.assertEqual(3, len(output_log))
-        self.assertEqual(output_log[1], upload_log)
+        self.assertEqual(upload_log, output_log[1])
 
     def _test_upload_download_activate_notification(self):
         request = unit_test_utils.get_fake_request()
@@ -376,7 +444,7 @@ class TestImagesController(base.StoreClearingUnitTest):
             'payload': activate_payload,
         }
         self.assertEqual(3, len(output_log))
-        self.assertEqual(output_log[2], activate_log)
+        self.assertEqual(activate_log, output_log[2])
 
     def test_restore_image_when_upload_failed(self):
         request = unit_test_utils.get_fake_request()
@@ -398,11 +466,11 @@ class TestImageDataDeserializer(test_utils.BaseTestCase):
     def test_upload(self):
         request = unit_test_utils.get_fake_request()
         request.headers['Content-Type'] = 'application/octet-stream'
-        request.body = 'YYY'
+        request.body = b'YYY'
         request.headers['Content-Length'] = 3
         output = self.deserializer.upload(request)
         data = output.pop('data')
-        self.assertEqual('YYY', data.read())
+        self.assertEqual(b'YYY', data.read())
         expected = {'size': 3}
         self.assertEqual(expected, output)
 
@@ -421,13 +489,13 @@ class TestImageDataDeserializer(test_utils.BaseTestCase):
     def test_upload_chunked_with_content_length(self):
         request = unit_test_utils.get_fake_request()
         request.headers['Content-Type'] = 'application/octet-stream'
-        request.body_file = six.StringIO('YYY')
+        request.body_file = six.BytesIO(b'YYY')
         # The deserializer shouldn't care if the Content-Length is
         # set when the user is attempting to send chunked data.
         request.headers['Content-Length'] = 3
         output = self.deserializer.upload(request)
         data = output.pop('data')
-        self.assertEqual('YYY', data.read())
+        self.assertEqual(b'YYY', data.read())
         expected = {'size': 3}
         self.assertEqual(expected, output)
 
@@ -437,24 +505,24 @@ class TestImageDataDeserializer(test_utils.BaseTestCase):
         # The deserializer shouldn't care if the Content-Length and
         # actual request body length differ. That job is left up
         # to the controller
-        request.body = 'YYY'
+        request.body = b'YYY'
         request.headers['Content-Length'] = 4
         output = self.deserializer.upload(request)
         data = output.pop('data')
-        self.assertEqual('YYY', data.read())
+        self.assertEqual(b'YYY', data.read())
         expected = {'size': 4}
         self.assertEqual(expected, output)
 
     def test_upload_wrong_content_type(self):
         request = unit_test_utils.get_fake_request()
         request.headers['Content-Type'] = 'application/json'
-        request.body = 'YYYYY'
+        request.body = b'YYYYY'
         self.assertRaises(webob.exc.HTTPUnsupportedMediaType,
                           self.deserializer.upload, request)
 
         request = unit_test_utils.get_fake_request()
         request.headers['Content-Type'] = 'application/octet-st'
-        request.body = 'YYYYY'
+        request.body = b'YYYYY'
         self.assertRaises(webob.exc.HTTPUnsupportedMediaType,
                           self.deserializer.upload, request)
 
@@ -470,9 +538,9 @@ class TestImageDataSerializer(test_utils.BaseTestCase):
         request.environ = {}
         response = webob.Response()
         response.request = request
-        image = FakeImage(size=3, data=iter('ZZZ'))
+        image = FakeImage(size=3, data=[b'Z', b'Z', b'Z'])
         self.serializer.download(response, image)
-        self.assertEqual('ZZZ', response.body)
+        self.assertEqual(b'ZZZ', response.body)
         self.assertEqual('3', response.headers['Content-Length'])
         self.assertNotIn('Content-MD5', response.headers)
         self.assertEqual('application/octet-stream',
@@ -484,9 +552,9 @@ class TestImageDataSerializer(test_utils.BaseTestCase):
         response = webob.Response()
         response.request = request
         checksum = '0745064918b49693cca64d6b6a13d28a'
-        image = FakeImage(size=3, checksum=checksum, data=iter('ZZZ'))
+        image = FakeImage(size=3, checksum=checksum, data=[b'Z', b'Z', b'Z'])
         self.serializer.download(response, image)
-        self.assertEqual('ZZZ', response.body)
+        self.assertEqual(b'ZZZ', response.body)
         self.assertEqual('3', response.headers['Content-Length'])
         self.assertEqual(checksum, response.headers['Content-MD5'])
         self.assertEqual('application/octet-stream',
