@@ -20,12 +20,12 @@ import uuid
 import mock
 from oslo_config import cfg
 from oslo_serialization import jsonutils
-from oslo_utils import timeutils
 # NOTE(jokke): simplified transition to py3, behaves like py2 xrange
 from six.moves import range
 import webob
 
 import glance.api.v2.tasks
+from glance.common import timeutils
 import glance.domain
 import glance.gateway
 from glance.tests.unit import base
@@ -179,7 +179,7 @@ class TestTasksController(test_utils.BaseTestCase):
         self.assertEqual(4, len(output['tasks']))
         actual = set([task.task_id for task in output['tasks']])
         expected = set([UUID1, UUID2, UUID3, UUID4])
-        self.assertEqual(sorted(actual), sorted(expected))
+        self.assertEqual(sorted(expected), sorted(actual))
 
     def test_index_with_many_filters(self):
         url = '/tasks?status=pending&type=import'
@@ -366,6 +366,47 @@ class TestTasksController(test_utils.BaseTestCase):
                                task_live_time.seconds / 3600)
         self.assertEqual(CONF.task.task_time_to_live, task_live_time_hour)
 
+    def test_create_with_wrong_import_form(self):
+        request = unit_test_utils.get_fake_request()
+        wrong_import_from = [
+            "swift://cloud.foo/myaccount/mycontainer/path",
+            "file:///path",
+            "s3://accesskey:secretkey@s3.amazonaws.com/bucket/key-id",
+            "cinder://volume-id"
+        ]
+        executor_factory = self.gateway.get_task_executor_factory(
+            request.context)
+        task_repo = self.gateway.get_task_repo(request.context)
+
+        for import_from in wrong_import_from:
+            task = {
+                "type": "import",
+                "input": {
+                    "import_from": import_from,
+                    "import_from_format": "qcow2",
+                    "image_properties": {
+                        "disk_format": "qcow2",
+                        "container_format": "bare",
+                        "name": "test-task"
+                    }
+                }
+            }
+            new_task = self.controller.create(request, task=task)
+            task_executor = executor_factory.new_task_executor(request.context)
+            task_executor.begin_processing(new_task.task_id)
+            final_task = task_repo.get(new_task.task_id)
+
+            self.assertEqual('failure', final_task.status)
+            if import_from.startswith("file:///"):
+                msg = ("File based imports are not allowed. Please use a "
+                       "non-local source of image data.")
+            else:
+                supported = ['http', ]
+                msg = ("The given uri is not valid. Please specify a "
+                       "valid uri from the following list of supported uri "
+                       "%(supported)s") % {'supported': supported}
+            self.assertEqual(msg, final_task.message)
+
     @mock.patch.object(glance.gateway.Gateway, 'get_task_factory')
     def test_notifications_on_create(self, mock_get_task_factory):
         request = unit_test_utils.get_fake_request()
@@ -441,7 +482,7 @@ class TestTasksDeserializer(test_utils.BaseTestCase):
 
     def test_create(self):
         request = unit_test_utils.get_fake_request()
-        request.body = jsonutils.dumps({
+        request.body = jsonutils.dump_as_bytes({
             'type': 'import',
             'input': {'import_from':
                       'swift://cloud.foo/myaccount/mycontainer/path',
@@ -749,7 +790,7 @@ class TestTasksSerializer(test_utils.BaseTestCase):
         self.serializer.create(response, self.fixtures[3])
 
         serialized_task = jsonutils.loads(response.body)
-        self.assertEqual(response.status_int, 201)
+        self.assertEqual(201, response.status_int)
         self.assertEqual(self.fixtures[3].task_id,
                          serialized_task['id'])
         self.assertEqual(self.fixtures[3].task_input,
@@ -763,7 +804,7 @@ class TestTasksSerializer(test_utils.BaseTestCase):
         self.serializer.create(response, self.fixtures[0])
 
         serialized_task = jsonutils.loads(response.body)
-        self.assertEqual(response.status_int, 201)
+        self.assertEqual(201, response.status_int)
         self.assertEqual(self.fixtures[0].task_id,
                          serialized_task['id'])
         self.assertEqual(self.fixtures[0].task_input,
@@ -776,7 +817,7 @@ class TestTasksSerializer(test_utils.BaseTestCase):
         self.serializer.create(response, self.fixtures[1])
 
         serialized_task = jsonutils.loads(response.body)
-        self.assertEqual(response.status_int, 201)
+        self.assertEqual(201, response.status_int)
         self.assertEqual(self.fixtures[1].task_id,
                          serialized_task['id'])
         self.assertEqual(self.fixtures[1].task_input,
